@@ -7,7 +7,7 @@
  * Classes:			DescriptorClass (Functions prefix: "DC_")
  *
  *
- * Comments:		See "notice.txt" for copyright and license information.
+ * Comments:		See "readme.txt" for copyright and license information.
  *-------
  */
 
@@ -191,7 +191,7 @@ void	DC_Destructor(DescriptorClass *self)
 }
 
 void InitializeEmbeddedDescriptor(DescriptorClass *desc, StatementClass *stmt,
-		 UInt4 desc_type) 
+		 UInt4 desc_type)
 {
 	DC_Constructor(desc, TRUE, stmt);
 	DC_get_conn(desc) = SC_get_conn(stmt);
@@ -202,20 +202,20 @@ void InitializeEmbeddedDescriptor(DescriptorClass *desc, StatementClass *stmt,
 		case SQL_ATTR_APP_ROW_DESC:
 			memset(desc + 1, 0, sizeof(ARDFields));
 			stmt->ard = (ARDClass *) desc;
-			break; 
+			break;
 		case SQL_ATTR_APP_PARAM_DESC:
 			memset(desc + 1, 0, sizeof(APDFields));
 			stmt->apd = (APDClass *) desc;
-			break; 
+			break;
 		case SQL_ATTR_IMP_ROW_DESC:
 			memset(desc + 1, 0, sizeof(IRDFields));
 			stmt->ird = (IRDClass *) desc;
 			stmt->ird->irdopts.stmt = stmt;
-			break; 
+			break;
 		case SQL_ATTR_IMP_PARAM_DESC:
 			memset(desc + 1, 0, sizeof(IPDFields));
 			stmt->ipd = (IPDClass *) desc;
-			break; 
+			break;
 	}
 }
 
@@ -260,6 +260,8 @@ BindInfoClass	*ARD_AllocBookmark(ARDFields *ardopts)
 char CC_add_descriptor(ConnectionClass *self, DescriptorClass *desc)
 {
 	int	i;
+	int	new_num_descs;
+	DescriptorClass **descs;
 
 	mylog("CC_add_descriptor: self=%p, desc=%p\n", self, desc);
 
@@ -273,15 +275,17 @@ char CC_add_descriptor(ConnectionClass *self, DescriptorClass *desc)
 		}
 	}
         /* no more room -- allocate more memory */
-	self->descs = (DescriptorClass **) realloc(self->descs, sizeof(DescriptorClass *) * (DESC_INCREMENT + self->num_descs));
-	if (!self->descs)
+	new_num_descs = DESC_INCREMENT + self->num_descs;
+	descs = (DescriptorClass **) realloc(self->descs, sizeof(DescriptorClass *) * new_num_descs);
+	if (!descs)
 		return FALSE;
+	self->descs = descs;
 
 	memset(&self->descs[self->num_descs], 0, sizeof(DescriptorClass *) *
 				DESC_INCREMENT);
         DC_get_conn(desc) = self;
 	self->descs[self->num_descs] = desc;
-	self->num_descs += DESC_INCREMENT;
+	self->num_descs = new_num_descs;
 
 	return TRUE;
 }
@@ -289,8 +293,9 @@ char CC_add_descriptor(ConnectionClass *self, DescriptorClass *desc)
 /*
  *	This API allocates a Application descriptor.
  */
-RETCODE SQL_API PGAPI_AllocDesc(HDBC ConnectionHandle,
-					SQLHDESC *DescriptorHandle)
+RETCODE SQL_API
+PGAPI_AllocDesc(HDBC ConnectionHandle,
+				SQLHDESC *DescriptorHandle)
 {
 	CSTR func = "PGAPI_AllocDesc";
 	ConnectionClass	*conn = (ConnectionClass *) ConnectionHandle;
@@ -309,7 +314,7 @@ RETCODE SQL_API PGAPI_AllocDesc(HDBC ConnectionHandle,
 			free(desc);
 			CC_set_error(conn, CONN_STMT_ALLOC_ERROR, "Maximum number of descriptors exceeded", func);
 			ret = SQL_ERROR;
-		} 
+		}
 	}
 	else
 	{
@@ -319,7 +324,8 @@ RETCODE SQL_API PGAPI_AllocDesc(HDBC ConnectionHandle,
 	return ret;
 }
 
-RETCODE SQL_API PGAPI_FreeDesc(SQLHDESC DescriptorHandle)
+RETCODE SQL_API
+PGAPI_FreeDesc(SQLHDESC DescriptorHandle)
 {
 	CSTR func = "PGAPI_FreeDesc";
 	DescriptorClass	*desc = (DescriptorClass *) DescriptorHandle;
@@ -416,7 +422,7 @@ static void IPDFields_copy(const IPDFields *src, IPDFields *target)
 	{
 		int	i;
 
-		target->parameters = (ParameterImplClass *) malloc(target->allocated * sizeof(ParameterInfoClass));
+		target->parameters = (ParameterImplClass *) malloc(target->allocated * sizeof(ParameterImplClass));
 		for (i = 0; i < target->allocated; i++)
 			ParameterImplClass_copy(&src->parameters[i], &target->parameters[i]);
 	}
@@ -424,7 +430,7 @@ static void IPDFields_copy(const IPDFields *src, IPDFields *target)
 
 RETCODE	SQL_API
 PGAPI_CopyDesc(SQLHDESC SourceDescHandle,
-			SQLHDESC TargetDescHandle)
+			   SQLHDESC TargetDescHandle)
 {
 	CSTR func = "PGAPI_CopyDesc";
 	RETCODE ret = SQL_ERROR;
@@ -566,7 +572,7 @@ static struct
 	{ DESC_ERROR_TAKEN_FROM_BACKEND, "HY000", "S1000" }, /* general error */
 	{ DESC_INTERNAL_ERROR, "HY000", "S1000" }, /* general error */
 	{ DESC_STILL_EXECUTING, "HY010", "S1010" },
-	{ DESC_NOT_IMPLEMENTED_ERROR, "HYC00", "S1C00" }, /* == 'driver not 
+	{ DESC_NOT_IMPLEMENTED_ERROR, "HYC00", "S1C00" }, /* == 'driver not
 							  * capable' */
 	{ DESC_BAD_PARAMETER_NUMBER_ERROR, "07009", "S1093" },
 	{ DESC_OPTION_OUT_OF_RANGE_ERROR, "HY092", "S1092" },
@@ -582,7 +588,7 @@ static struct
 	{ DESC_INVALID_CURSOR_POSITION, "HY109", "S1109" },
 	{ DESC_VALUE_OUT_OF_RANGE, "HY019", "22003" },
 	{ DESC_OPERATION_INVALID, "HY011", "S1011" },
-	{ DESC_PROGRAM_TYPE_OUT_OF_RANGE, "?????", "?????" }, 
+	{ DESC_PROGRAM_TYPE_OUT_OF_RANGE, "?????", "?????" },
 	{ DESC_BAD_ERROR, "08S01", "08S01" }, /* communication link failure */
 	{ DESC_INVALID_OPTION_IDENTIFIER, "HY092", "HY092" },
 	{ DESC_RETURN_NULL_WITHOUT_INDICATOR, "22002", "22002" },
@@ -613,7 +619,7 @@ static	PG_ErrorInfo	*DC_create_errorinfo(const DescriptorClass *desc)
 	if (errornum < 0 ||
 	    errornum >= sizeof(Descriptor_sqlstate) / sizeof(Descriptor_sqlstate[0]))
 		errornum = 1 - LOWEST_DESC_ERROR;
-	strcpy(error->sqlstate, env_is_odbc3 ? Descriptor_sqlstate[errornum].ver3str : Descriptor_sqlstate[errornum].ver2str); 
+	strcpy(error->sqlstate, env_is_odbc3 ? Descriptor_sqlstate[errornum].ver3str : Descriptor_sqlstate[errornum].ver2str);
         return error;
 }
 void
@@ -629,14 +635,14 @@ DC_log_error(const char *func, const char *desc, const DescriptorClass *self)
 
 /*		Returns the next SQL error information. */
 RETCODE		SQL_API
-PGAPI_DescError(	SQLHDESC hdesc,
-			SQLSMALLINT	RecNumber,
-			SQLCHAR FAR * szSqlState,
-			SQLINTEGER FAR * pfNativeError,
-			SQLCHAR FAR * szErrorMsg,
-			SQLSMALLINT cbErrorMsgMax,
-			SQLSMALLINT FAR * pcbErrorMsg,
-			UWORD flag)
+PGAPI_DescError(SQLHDESC hdesc,
+				SQLSMALLINT	RecNumber,
+				SQLCHAR FAR * szSqlState,
+				SQLINTEGER FAR * pfNativeError,
+				SQLCHAR FAR * szErrorMsg,
+				SQLSMALLINT cbErrorMsgMax,
+				SQLSMALLINT FAR * pcbErrorMsg,
+				UWORD flag)
 {
 	CSTR func = "PGAPI_DescError";
 	/* CC: return an error of a hdesc  */
