@@ -19,6 +19,7 @@
 /* Multibyte support	Eiji Tokuya 2001-03-15 */
 
 #include "dlg_specific.h"
+#include "misc.h" // strncpy_null
 #include "win_setup.h"
 
 #include "convert.h"
@@ -63,10 +64,11 @@ SetDlgStuff(HWND hdlg, const ConnInfo *ci)
 	SetDlgItemText(hdlg, IDC_DATABASE, ci->database);
 	SetDlgItemText(hdlg, IDC_SERVER, ci->server);
 	SetDlgItemText(hdlg, IDC_USER, ci->username);
-	SetDlgItemText(hdlg, IDC_PASSWORD, ci->password);
+	SetDlgItemText(hdlg, IDC_PASSWORD, SAFE_NAME(ci->password));
 	SetDlgItemText(hdlg, IDC_PORT, ci->port);
 
 	dsplevel = 0;
+#ifdef USE_LIBPQ
 	libpq_exist = SSLLIB_check();
 mylog("libpq_exist=%d\n", libpq_exist);
 	if (libpq_exist)
@@ -75,11 +77,13 @@ mylog("libpq_exist=%d\n", libpq_exist);
 		dsplevel = 2;
 	}
 	else
+#endif /* USE_LIBPQ */
 	{
 mylog("SendMessage CTL_COLOR\n");
 		SendMessage(GetDlgItem(hdlg, IDC_NOTICE_USER), WM_CTLCOLOR, 0, 0);
 #ifdef	USE_SSPI
-		dsplevel = 1;
+		ShowWindow(GetDlgItem(hdlg, IDC_NOTICE_USER), SW_HIDE);
+		dsplevel = 2;
 #endif /* USE_SSPI */
 	}
 
@@ -98,7 +102,7 @@ mylog("SendMessage CTL_COLOR\n");
 			break;
 		dsplevel++;
 	}
-	
+
 	dspcount = dspcount_bylevel[dsplevel];
 	for (i = 0; i < dspcount; i++)
 	{
@@ -114,13 +118,15 @@ void
 GetDlgStuff(HWND hdlg, ConnInfo *ci)
 {
 	int	sslposition;
+	char	medium_buf[MEDIUM_REGISTRY_LEN];
 
 	GetDlgItemText(hdlg, IDC_DESC, ci->desc, sizeof(ci->desc));
 
 	GetDlgItemText(hdlg, IDC_DATABASE, ci->database, sizeof(ci->database));
 	GetDlgItemText(hdlg, IDC_SERVER, ci->server, sizeof(ci->server));
 	GetDlgItemText(hdlg, IDC_USER, ci->username, sizeof(ci->username));
-	GetDlgItemText(hdlg, IDC_PASSWORD, ci->password, sizeof(ci->password));
+	GetDlgItemText(hdlg, IDC_PASSWORD, medium_buf, sizeof(medium_buf));
+	STR_TO_NAME(ci->password, medium_buf);
 	GetDlgItemText(hdlg, IDC_PORT, ci->port, sizeof(ci->port));
 	sslposition = (int)(DWORD)SendMessage(GetDlgItem(hdlg, IDC_SSLMODE), CB_GETCURSEL, 0L, 0L);
 	strncpy_null(ci->sslmode, modetab[sslposition].modestr, sizeof(ci->sslmode));
@@ -214,7 +220,7 @@ driver_optionsDraw(HWND hdlg, const ConnInfo *ci, int src, BOOL enable)
 	SetDlgItemText(hdlg, DRV_EXTRASYSTABLEPREFIXES, comval->extra_systable_prefixes);
 
 	/* Driver Connection Settings */
-	SetDlgItemText(hdlg, DRV_CONNSETTINGS, comval->conn_settings);
+	SetDlgItemText(hdlg, DRV_CONNSETTINGS, SAFE_NAME(comval->conn_settings));
 	EnableWindow(GetDlgItem(hdlg, DRV_CONNSETTINGS), enable);
 	ShowWindow(GetDlgItem(hdlg, IDPREVPAGE), enable ? SW_HIDE : SW_SHOW);
 	ShowWindow(GetDlgItem(hdlg, IDNEXTPAGE), enable ? SW_HIDE : SW_SHOW);
@@ -268,7 +274,13 @@ driver_options_update(HWND hdlg, ConnInfo *ci, const char *updateDriver)
 
 	/* Driver Connection Settings */
 	if (!ci)
-		GetDlgItemText(hdlg, DRV_CONNSETTINGS, comval->conn_settings, sizeof(comval->conn_settings));
+	{
+		char	conn_settings[LARGE_REGISTRY_LEN];
+
+		GetDlgItemText(hdlg, DRV_CONNSETTINGS, conn_settings, sizeof(conn_settings));
+		if ('\0' != conn_settings[0])
+			STR_TO_NAME(comval->conn_settings, conn_settings);
+	}
 
 	if (updateDriver)
 	{
@@ -295,9 +307,9 @@ driver_optionsProc(HWND hdlg,
 		case WM_INITDIALOG:
 			SetWindowLongPtr(hdlg, DWLP_USER, lParam);		/* save for OK etc */
 			ci = (ConnInfo *) lParam;
-			LoadString(s_hModule, IDS_ADVANCE_OPTION_DEF, strbuf, sizeof(strbuf)); 
+			LoadString(s_hModule, IDS_ADVANCE_OPTION_DEF, strbuf, sizeof(strbuf));
 			SetWindowText(hdlg, strbuf);
-			LoadString(s_hModule, IDS_ADVANCE_SAVE, strbuf, sizeof(strbuf)); 
+			LoadString(s_hModule, IDS_ADVANCE_SAVE, strbuf, sizeof(strbuf));
 			SetWindowText(GetDlgItem(hdlg, IDOK), strbuf);
 			ShowWindow(GetDlgItem(hdlg, IDAPPLY), SW_HIDE);
 			driver_optionsDraw(hdlg, ci, 0, TRUE);
@@ -439,7 +451,7 @@ ds_options1Proc(HWND hdlg,
 			}
 			else
 			{
-				LoadString(s_hModule, IDS_ADVANCE_OPTION_CON1, strbuf, sizeof(strbuf)); 
+				LoadString(s_hModule, IDS_ADVANCE_OPTION_CON1, strbuf, sizeof(strbuf));
 				SetWindowText(hdlg, strbuf);
 				ShowWindow(GetDlgItem(hdlg, IDAPPLY), SW_HIDE);
 			}
@@ -471,9 +483,8 @@ ds_options1Proc(HWND hdlg,
 
 					EndDialog(hdlg, FALSE);
 					DialogBoxParam(s_hModule,
-						MAKEINTRESOURCE(DLG_OPTIONS_DS),
-                                                 	hdlg, ds_options2Proc, (LPARAM)
-ci);
+								   MAKEINTRESOURCE(DLG_OPTIONS_DS),
+								   hdlg, ds_options2Proc, (LPARAM) ci);
 					break;
 			}
 	}
@@ -515,7 +526,7 @@ ds_options2Proc(HWND hdlg,
 			}
 			else
 			{
-				LoadString(s_hModule, IDS_ADVANCE_OPTION_CON2, buf, sizeof(buf)); 
+				LoadString(s_hModule, IDS_ADVANCE_OPTION_CON2, buf, sizeof(buf));
 				SetWindowText(hdlg, buf);
 				ShowWindow(GetDlgItem(hdlg, IDAPPLY), SW_HIDE);				}
 
@@ -589,13 +600,13 @@ ds_options2Proc(HWND hdlg,
 			/*CheckDlgButton(hdlg, DS_LOWERCASEIDENTIFIER, ci->lower_case_identifier);*/
 			CheckDlgButton(hdlg, DS_GSSAUTHUSEGSSAPI, ci->gssauth_use_gssapi);
 
-#if	defined(NOT_USE_LIBPQ) && !defined(USE_SSPI) && !defined(USE_GSS)
+#if	!defined(USE_LIBPQ) && !defined(USE_SSPI) && !defined(USE_GSS)
 			EnableWindow(GetDlgItem(hdlg, DS_GSSAUTHUSEGSSAPI), FALSE);
 #endif
 			EnableWindow(GetDlgItem(hdlg, DS_FAKEOIDINDEX), atoi(ci->show_oid_column));
 
 			/* Datasource Connection Settings */
-			SetDlgItemText(hdlg, DS_CONNSETTINGS, ci->conn_settings);
+			SetDlgItemText(hdlg, DS_CONNSETTINGS, SAFE_NAME(ci->conn_settings));
 			break;
 
 		case WM_COMMAND:
@@ -670,7 +681,12 @@ ds_options2Proc(HWND hdlg,
 					sprintf(ci->show_oid_column, "%d", IsDlgButtonChecked(hdlg, DS_SHOWOIDCOLUMN));
 
 					/* Datasource Connection Settings */
-					GetDlgItemText(hdlg, DS_CONNSETTINGS, ci->conn_settings, sizeof(ci->conn_settings));
+					{
+						char conn_settings[LARGE_REGISTRY_LEN];
+						GetDlgItemText(hdlg, DS_CONNSETTINGS, conn_settings, sizeof(conn_settings));
+						if ('\0' != conn_settings[0])
+							STR_TO_NAME(ci->conn_settings, conn_settings);
+					}
 					if (IDAPPLY == cmd)
 					{
 						SendMessage(GetWindow(hdlg, GW_OWNER), WM_COMMAND, wParam, lParam);
@@ -678,11 +694,11 @@ ds_options2Proc(HWND hdlg,
 					}
 
 					EndDialog(hdlg, cmd == IDOK);
-					if (IDOK == cmd) 
+					if (IDOK == cmd)
 						return TRUE;
 					DialogBoxParam(s_hModule,
-						MAKEINTRESOURCE(DLG_OPTIONS_DRV),
-                                         	hdlg, ds_options1Proc, (LPARAM) ci);
+								   MAKEINTRESOURCE(DLG_OPTIONS_DRV),
+								   hdlg, ds_options1Proc, (LPARAM) ci);
 					break;
 
 				case IDCANCEL:
@@ -717,17 +733,17 @@ makeDriversList(HWND lwnd, const ConnInfo *ci)
 	do
 	{
 		ret = SQLDrivers(henv, direction,
-			drvname, sizeof(drvname), &drvncount, 
-			drvatt, sizeof(drvatt), &drvacount); 
+						 drvname, sizeof(drvname), &drvncount,
+						 drvatt, sizeof(drvatt), &drvacount);
 		if (SQL_SUCCESS != ret && SQL_SUCCESS_WITH_INFO != ret)
 			break;
 		if (strnicmp(drvname, "postgresql", 10) == 0)
 		{
 			iidx = SendMessage(lwnd, LB_ADDSTRING, 0, (LPARAM) drvname);
 			if (LB_ERR != iidx && stricmp(drvname, ci->drivername) == 0)
-{
+			{
 				SendMessage(lwnd, LB_SETCURSEL, (WPARAM) iidx, (LPARAM) 0);
-}
+			}
 			lcount++;
 		}
 		direction = SQL_FETCH_NEXT;
@@ -741,7 +757,7 @@ makeDriversList(HWND lwnd, const ConnInfo *ci)
 
 LRESULT		CALLBACK
 manage_dsnProc(HWND hdlg, UINT wMsg,
-		WPARAM wParam, LPARAM lParam)
+			   WPARAM wParam, LPARAM lParam)
 {
 	LPSETUPDLG	lpsetupdlg;
 	ConnInfo	*ci;
@@ -766,11 +782,11 @@ manage_dsnProc(HWND hdlg, UINT wMsg,
 					lpsetupdlg = (LPSETUPDLG) GetWindowLongPtr(hdlg, DWLP_USER);
 					lwnd = GetDlgItem(hdlg, IDC_DRIVER_LIST);
 					sidx = SendMessage(lwnd, LB_GETCURSEL,
-						(WPARAM) 0, (LPARAM) 0);
+									   (WPARAM) 0, (LPARAM) 0);
 					if (LB_ERR == sidx)
 						return FALSE;
 					sidx = SendMessage(lwnd, LB_GETTEXT,
-						(WPARAM) sidx, (LPARAM) drvname);
+									   (WPARAM) sidx, (LPARAM) drvname);
 					if (LB_ERR == sidx)
 						return FALSE;
 					ChangeDriverName(hdlg, lpsetupdlg, drvname);
