@@ -43,20 +43,20 @@ pthread_mutex_t     common_cs;
 pthread_mutex_t     common_lcs;
 #endif /* WIN_MULTITHREAD_SUPPORT */
 
-void	shortterm_common_lock()
+void	shortterm_common_lock(void)
 {
 	ENTER_COMMON_CS;
 }
-void	shortterm_common_unlock()
+void	shortterm_common_unlock(void)
 {
 	LEAVE_COMMON_CS;
 }
 
-int	getConnCount()
+int	getConnCount(void)
 {
 	return conns_count;
 }
-ConnectionClass * const *getConnList()
+ConnectionClass * const *getConnList(void)
 {
 	return conns;
 }
@@ -119,12 +119,13 @@ cleanup:
 
 
 static void
-pg_sqlstate_set(const EnvironmentClass *env, UCHAR *szSqlState, const UCHAR *ver3str, const UCHAR *ver2str)
+pg_sqlstate_set(const EnvironmentClass *env, UCHAR *szSqlState, const char *ver3str, const char *ver2str)
 {
-	strcpy(szSqlState, EN_is_odbc3(env) ? ver3str : ver2str);
+	strcpy((char *) szSqlState, EN_is_odbc3(env) ? ver3str : ver2str);
 }
 
-PG_ErrorInfo	*ER_Constructor(SDWORD errnumber, const char *msg)
+PG_ErrorInfo *
+ER_Constructor(SDWORD errnumber, const char *msg)
 {
 	PG_ErrorInfo	*error;
 	ssize_t		aladd, errsize;
@@ -150,7 +151,7 @@ PG_ErrorInfo	*ER_Constructor(SDWORD errnumber, const char *msg)
 		if (errsize > 0)
 			memcpy(error->__error_message, msg, errsize);
 		error->__error_message[aladd] = '\0';
-        	error->recsize = -1;
+		error->recsize = -1;
 	}
 	return error;
 }
@@ -161,7 +162,8 @@ ER_Destructor(PG_ErrorInfo *self)
 	free(self);
 }
 
-PG_ErrorInfo *ER_Dup(const PG_ErrorInfo *self)
+PG_ErrorInfo *
+ER_Dup(const PG_ErrorInfo *self)
 {
 	PG_ErrorInfo	*new;
 	Int4		alsize;
@@ -181,13 +183,13 @@ PG_ErrorInfo *ER_Dup(const PG_ErrorInfo *self)
 /*		Returns the next SQL error information. */
 RETCODE		SQL_API
 ER_ReturnError(PG_ErrorInfo **pgerror,
-		SQLSMALLINT	RecNumber,
-		SQLCHAR FAR * szSqlState,
-		SQLINTEGER FAR * pfNativeError,
-		SQLCHAR FAR * szErrorMsg,
-		SQLSMALLINT cbErrorMsgMax,
-		SQLSMALLINT FAR * pcbErrorMsg,
-		UWORD flag)
+			   SQLSMALLINT	RecNumber,
+			   SQLCHAR FAR * szSqlState,
+			   SQLINTEGER FAR * pfNativeError,
+			   SQLCHAR FAR * szErrorMsg,
+			   SQLSMALLINT cbErrorMsgMax,
+			   SQLSMALLINT FAR * pcbErrorMsg,
+			   UWORD flag)
 {
 	CSTR func = "ER_ReturnError";
 	/* CC: return an error of a hstmt  */
@@ -206,7 +208,7 @@ ER_ReturnError(PG_ErrorInfo **pgerror,
 	/*
 	 *	Even though an application specifies a larger error message
 	 *	buffer, the driver manager changes it silently.
-	 *	Therefore we divide the error message into ... 
+	 *	Therefore we divide the error message into ...
 	 */
 	if (error->recsize < 0)
 	{
@@ -224,19 +226,19 @@ ER_ReturnError(PG_ErrorInfo **pgerror,
 	}
 	stapos = (RecNumber - 1) * error->recsize;
 	if (stapos > msglen)
-		return SQL_NO_DATA_FOUND; 
+		return SQL_NO_DATA_FOUND;
 	pcblen = wrtlen = msglen - stapos;
 	if (pcblen > error->recsize)
 		pcblen = error->recsize;
 	if (0 == cbErrorMsgMax)
-		wrtlen = 0; 
+		wrtlen = 0;
 	else if (wrtlen >= cbErrorMsgMax)
 	{
 		if (partial_ok)
 			wrtlen = cbErrorMsgMax - 1;
 		else if (cbErrorMsgMax <= error->recsize)
 			wrtlen = 0;
-		else 
+		else
 			wrtlen = error->recsize;
 	}
 	if (wrtlen > pcblen)
@@ -254,7 +256,7 @@ ER_ReturnError(PG_ErrorInfo **pgerror,
 		*pfNativeError = error->status;
 
 	if (NULL != szSqlState)
-		strncpy_null(szSqlState, error->sqlstate, 6);
+		strncpy_null((char *) szSqlState, error->sqlstate, 6);
 
 	mylog("	     szSqlState = '%s',len=%d, szError='%s'\n", szSqlState, pcblen, szErrorMsg);
 	if (clear_str)
@@ -274,14 +276,14 @@ ER_ReturnError(PG_ErrorInfo **pgerror,
 
 
 RETCODE		SQL_API
-PGAPI_ConnectError(	HDBC hdbc,
-			SQLSMALLINT	RecNumber,
-			SQLCHAR FAR * szSqlState,
-			SQLINTEGER FAR * pfNativeError,
-			SQLCHAR FAR * szErrorMsg,
-			SQLSMALLINT cbErrorMsgMax,
-			SQLSMALLINT FAR * pcbErrorMsg,
-			UWORD flag)
+PGAPI_ConnectError(HDBC hdbc,
+				   SQLSMALLINT	RecNumber,
+				   SQLCHAR FAR * szSqlState,
+				   SQLINTEGER FAR * pfNativeError,
+				   SQLCHAR FAR * szErrorMsg,
+				   SQLSMALLINT cbErrorMsgMax,
+				   SQLSMALLINT FAR * pcbErrorMsg,
+				   UWORD flag)
 {
 	ConnectionClass *conn = (ConnectionClass *) hdbc;
 	EnvironmentClass *env = (EnvironmentClass *) conn->henv;
@@ -299,7 +301,7 @@ PGAPI_ConnectError(	HDBC hdbc,
 	{
 		mylog("CC_Get_error returned nothing.\n");
 		if (NULL != szSqlState)
-			strcpy(szSqlState, "00000");
+			strcpy((char *) szSqlState, "00000");
 		if (NULL != pcbErrorMsg)
 			*pcbErrorMsg = 0;
 		if ((NULL != szErrorMsg) && (cbErrorMsgMax > 0))
@@ -319,15 +321,15 @@ PGAPI_ConnectError(	HDBC hdbc,
 			*pcbErrorMsg = cbErrorMsgMax - 1;
 	}
 	if ((NULL != szErrorMsg) && (cbErrorMsgMax > 0))
-		strncpy_null(szErrorMsg, msg, cbErrorMsgMax);
+		strncpy_null((char *) szErrorMsg, msg, cbErrorMsgMax);
 	if (NULL != pfNativeError)
 		*pfNativeError = status;
 
 	if (NULL != szSqlState)
 	{
 		if (conn->sqlstate[0])
-			strcpy(szSqlState, conn->sqlstate);
-		else	
+			strcpy((char *) szSqlState, conn->sqlstate);
+		else
 		switch (status)
 		{
 			case CONN_OPTION_VALUE_CHANGED:
@@ -408,14 +410,14 @@ PGAPI_ConnectError(	HDBC hdbc,
 }
 
 RETCODE		SQL_API
-PGAPI_EnvError(		HENV henv,
-			SQLSMALLINT	RecNumber,
-			SQLCHAR FAR * szSqlState,
-			SQLINTEGER FAR * pfNativeError,
-			SQLCHAR FAR * szErrorMsg,
-			SQLSMALLINT cbErrorMsgMax,
-			SQLSMALLINT FAR * pcbErrorMsg,
-			UWORD flag)
+PGAPI_EnvError(HENV henv,
+			   SQLSMALLINT	RecNumber,
+			   SQLCHAR FAR * szSqlState,
+			   SQLINTEGER FAR * pfNativeError,
+			   SQLCHAR FAR * szErrorMsg,
+			   SQLSMALLINT cbErrorMsgMax,
+			   SQLSMALLINT FAR * pcbErrorMsg,
+			   UWORD flag)
 {
 	EnvironmentClass *env = (EnvironmentClass *) henv;
 	char		*msg;
@@ -428,8 +430,8 @@ PGAPI_EnvError(		HENV henv,
 		return SQL_ERROR;
 	if (!EN_get_error(env, &status, &msg) || NULL == msg)
 	{
-			mylog("EN_get_error: status = %d, msg = #%s#\n", status, msg);
-		
+		mylog("EN_get_error: status = %d, msg = #%s#\n", status, msg);
+
 		if (NULL != szSqlState)
 			pg_sqlstate_set(env, szSqlState, "00000", "00000");
 		if (NULL != pcbErrorMsg)
@@ -444,7 +446,7 @@ PGAPI_EnvError(		HENV henv,
 	if (NULL != pcbErrorMsg)
 		*pcbErrorMsg = (SQLSMALLINT) strlen(msg);
 	if ((NULL != szErrorMsg) && (cbErrorMsgMax > 0))
-		strncpy_null(szErrorMsg, msg, cbErrorMsgMax);
+		strncpy_null((char *) szErrorMsg, msg, cbErrorMsgMax);
 	if (NULL != pfNativeError)
 		*pfNativeError = status;
 
@@ -469,8 +471,7 @@ PGAPI_EnvError(		HENV henv,
 
 /*		Returns the next SQL error information. */
 RETCODE		SQL_API
-PGAPI_Error(
-			HENV henv,
+PGAPI_Error(HENV henv,
 			HDBC hdbc,
 			HSTMT hstmt,
 			SQLCHAR FAR * szSqlState,
@@ -498,7 +499,7 @@ PGAPI_Error(
 	else
 	{
 		if (NULL != szSqlState)
-			strcpy(szSqlState, "00000");
+			strcpy((char *) szSqlState, "00000");
 		if (NULL != pcbErrorMsg)
 			*pcbErrorMsg = 0;
 		if ((NULL != szErrorMsg) && (cbErrorMsgMax > 0))
@@ -667,7 +668,7 @@ EN_add_connection(EnvironmentClass *self, ConnectionClass *conn)
 	ret = TRUE;
 	mylog("       added at %d, conn->henv = %p, conns[%d]->henv = %p\n", conns_count, conn->henv, conns_count, conns[conns_count]->henv);
 	for (i = conns_count + 1; i < alloc; i++)
-		conns[i] = NULL; 
+		conns[i] = NULL;
 	conns_count = alloc;
 cleanup:
 	LEAVE_CONNS_CS;
