@@ -13,6 +13,7 @@
  */
 
 #include "psqlodbc.h"
+#include "misc.h"
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -110,7 +111,7 @@ strncpy_null(char *dst, const char *src, ssize_t len)
  *------
  */
 char *
-make_string(const char *s, ssize_t len, char *buf, size_t bufsize)
+make_string(const SQLCHAR *s, SQLINTEGER len, char *buf, size_t bufsize)
 {
 	size_t		length;
 	char	   *str;
@@ -120,7 +121,7 @@ make_string(const char *s, ssize_t len, char *buf, size_t bufsize)
 	if (len >= 0)
 		length =len;
 	else if (SQL_NTS == len)
-		length = strlen(s);
+		length = strlen((char *) s);
 	else
 	{
 		mylog("make_string invalid length=%d\n", len);
@@ -128,7 +129,7 @@ make_string(const char *s, ssize_t len, char *buf, size_t bufsize)
 	}
 	if (buf)
 	{
-		strncpy_null(buf, s, bufsize > length ? length + 1 : bufsize);
+		strncpy_null(buf, (char *) s, bufsize > length ? length + 1 : bufsize);
 		return buf;
 	}
 
@@ -138,7 +139,7 @@ inolog("str=%p\n", str);
 	if (!str)
 		return NULL;
 
-	strncpy_null(str, s, length + 1);
+	strncpy_null(str, (char *) s, length + 1);
 	return str;
 }
 
@@ -158,11 +159,11 @@ make_lstring_ifneeded(ConnectionClass *conn, const SQLCHAR *s, ssize_t len, BOOL
 	if (s && (len > 0 || (len == SQL_NTS && (length = strlen(ccs)) > 0)))
 	{
 		int	i;
-		const char *ptr;
+		const UCHAR *ptr;
 		encoded_str encstr;
 
 		make_encoded_str(&encstr, conn, ccs);
-		for (i = 0, ptr = ccs; i < length; i++, ptr++)
+		for (i = 0, ptr = (const UCHAR *) ccs; i < length; i++, ptr++)
 		{
 			encoded_nextchar(&encstr);
 			if (ENCODE_STATUS(encstr) != 0)
@@ -175,7 +176,7 @@ make_lstring_ifneeded(ConnectionClass *conn, const SQLCHAR *s, ssize_t len, BOOL
 					str = NULL;
 				}
 				break;
-			} 
+			}
 			if (tolower(*ptr) != *ptr)
 			{
 				if (!str)
@@ -199,13 +200,12 @@ make_lstring_ifneeded(ConnectionClass *conn, const SQLCHAR *s, ssize_t len, BOOL
  *	This is heavily used in creating queries for info routines (SQLTables, SQLColumns).
  *	This routine could be modified to use vsprintf() to handle multiple arguments.
  */
-char *
+static char *
 my_strcat(char *buf, const char *fmt, const char *s, ssize_t len)
 {
 	if (s && (len > 0 || (len == SQL_NTS && strlen(s) > 0)))
 	{
 		size_t			length = (len > 0) ? len : strlen(s);
-
 		size_t			pos = strlen(buf);
 
 		sprintf(&buf[pos], fmt, length, s);
@@ -215,7 +215,7 @@ my_strcat(char *buf, const char *fmt, const char *s, ssize_t len)
 }
 
 char *
-schema_strcat(char *buf, const char *fmt, const char *s, ssize_t len, const char *tbname, int tbnmlen, ConnectionClass *conn)
+schema_strcat(char *buf, const char *fmt, const SQLCHAR *s, SQLLEN len, const SQLCHAR *tbname, SQLLEN tbnmlen, ConnectionClass *conn)
 {
 	if (!s || 0 == len)
 	{
@@ -228,33 +228,18 @@ schema_strcat(char *buf, const char *fmt, const char *s, ssize_t len, const char
 			return my_strcat(buf, fmt, CC_get_current_schema(conn), SQL_NTS);
 		return NULL;
 	}
-	return my_strcat(buf, fmt, s, len);
+	return my_strcat(buf, fmt, (char *) s, len);
 }
 
-
-void
-remove_newlines(char *string)
-{
-	size_t i, len = strlen(string);
-
-	for (i = 0; i < len; i++)
-	{
-		if ((PG_LINEFEED == string[i]) ||
-			(PG_CARRIAGE_RETURN == string[i]))
-			string[i] = ' ';
-	}
-}
-
-
 char *
 my_trim(char *s)
 {
-	size_t	i;
+	char *last;
 
-	for (i = strlen(s) - 1; i >= 0; i--)
+	for (last = s + strlen(s) - 1; last >= s; last--)
 	{
-		if (s[i] == ' ')
-			s[i] = '\0';
+		if (*last == ' ')
+			*last = '\0';
 		else
 			break;
 	}
@@ -266,7 +251,7 @@ my_trim(char *s)
  *	my_strcat1 is a extension of my_strcat.
  *	It can have 1 more parameter than my_strcat.
  */
-char *
+static char *
 my_strcat1(char *buf, const char *fmt, const char *s1, const char *s, ssize_t len)
 {
 	ssize_t	length = len;
@@ -285,7 +270,7 @@ my_strcat1(char *buf, const char *fmt, const char *s1, const char *s, ssize_t le
 }
 
 char *
-schema_strcat1(char *buf, const char *fmt, const char *s1, const char *s, ssize_t len, const char *tbname, int tbnmlen, ConnectionClass *conn)
+schema_strcat1(char *buf, const char *fmt, const char *s1, const char *s, ssize_t len, const SQLCHAR *tbname, int tbnmlen, ConnectionClass *conn)
 {
 	if (!s || 0 == len)
 	{
@@ -307,7 +292,7 @@ snprintf_add(char *buf, size_t size, const char *format, ...)
 	int len;
 	size_t pos = strlen(buf);
 	va_list arglist;
-	
+
 	va_start(arglist, format);
 	len = vsnprintf(buf + pos, size - pos, format, arglist);
 	va_end(arglist);
@@ -324,7 +309,7 @@ snprintf_len(char *buf, size_t size, const char *format, ...)
 {
 	ssize_t len;
 	va_list arglist;
-	
+
 	va_start(arglist, format);
 	if ((len = vsnprintf(buf, size, format, arglist)) < 0)
 		len = size;
@@ -339,11 +324,11 @@ strlcat(char *dst, const char *src, size_t size)
 	size_t ttllen;
 	char	*pd = dst;
 	const char *ps= src;
-	
+
 	for (ttllen = 0; ttllen < size; ttllen++, pd++)
 	{
 		if (0 == *pd)
-			break; 
+			break;
 	}
 	if (ttllen >= size - 1)
 		return ttllen + strlen(src);
@@ -358,3 +343,43 @@ strlcat(char *dst, const char *src, size_t size)
 	return ttllen;
 }
 #endif /* HAVE_STRLCAT */
+
+
+/*
+ * Proprly quote and escape a possibly schema-qualified table name.
+ * Returns a statically allocated buffer.
+ */
+char *
+quote_table(const pgNAME schema, pgNAME table)
+{
+	static char buf[200];
+	const char *ptr;
+	int			i;
+
+	i = 0;
+
+	if (NAME_IS_VALID(schema))
+	{
+		buf[i++] = '"';
+		for (ptr = SAFE_NAME(schema); *ptr != '\0' && i < sizeof(buf) - 6; ptr++)
+		{
+			buf[i++] = *ptr;
+			if (*ptr == '"')
+				buf[i++] = '"';		/* escape quotes by doubling them */
+		}
+		buf[i++] = '"';
+		buf[i++] = '.';
+	}
+
+	buf[i++] = '"';
+	for (ptr = SAFE_NAME(table); *ptr != '\0' && i < sizeof(buf) - 3; ptr++)
+	{
+		buf[i++] = *ptr;
+		if (*ptr == '"')
+			buf[i++] = '"'; 		/* escape quotes by doubling them */
+	}
+	buf[i++] = '"';
+	buf[i] = '\0';
+
+	return buf;
+}
