@@ -149,7 +149,7 @@ SQLColumns(HSTMT StatementHandle,
 		ret = PGAPI_Columns(StatementHandle, ctName, NameLength1,
 				scName, NameLength2, tbName, NameLength3,
 				clName, NameLength4, flag, 0, 0);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newTb = NULL, *newCl = NULL;
@@ -166,7 +166,7 @@ SQLColumns(HSTMT StatementHandle,
 		{
 			scName = newSc;
 			reexec = TRUE;
-		}	
+		}
 		if (newTb = make_lstring_ifneeded(conn, TableName, NameLength3, ifallupper), NULL != newTb)
 		{
 			tbName = newTb;
@@ -241,8 +241,7 @@ SQLDriverConnect(HDBC hdbc,
 	return ret;
 }
 RETCODE		SQL_API
-SQLBrowseConnect(
-				 HDBC hdbc,
+SQLBrowseConnect(HDBC hdbc,
 				 SQLCHAR *szConnStrIn,
 				 SQLSMALLINT cbConnStrIn,
 				 SQLCHAR *szConnStrOut,
@@ -428,7 +427,7 @@ SQLFetch(HSTMT StatementHandle)
 	return ret;
 }
 
-#if (ODBCVER < 0x0300) 
+#if (ODBCVER < 0x0300)
 RETCODE		SQL_API
 SQLFreeConnect(HDBC ConnectionHandle)
 {
@@ -448,7 +447,7 @@ SQLFreeEnv(HENV EnvironmentHandle)
 	ret = PGAPI_FreeEnv(EnvironmentHandle);
 	return ret;
 }
-#endif /* ODBCVER */ 
+#endif /* ODBCVER */
 
 RETCODE		SQL_API
 SQLFreeStmt(HSTMT StatementHandle,
@@ -832,7 +831,7 @@ SQLSpecialColumns(HSTMT StatementHandle,
 		ret = PGAPI_SpecialColumns(StatementHandle, IdentifierType, ctName,
 			NameLength1, scName, NameLength2, tbName, NameLength3,
 							Scope, Nullable);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt =NULL, *newSc = NULL, *newTb = NULL;
@@ -895,7 +894,7 @@ SQLStatistics(HSTMT StatementHandle,
 		ret = PGAPI_Statistics(StatementHandle, ctName, NameLength1,
 				 scName, NameLength2, tbName, NameLength3,
 				 Unique, Reserved);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt =NULL, *newSc = NULL, *newTb = NULL;
@@ -929,7 +928,7 @@ SQLStatistics(HSTMT StatementHandle,
 				free(newSc);
 			if (newTb)
 				free(newTb);
-		}	
+		}
 	}
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
@@ -963,7 +962,7 @@ SQLTables(HSTMT StatementHandle,
 		ret = PGAPI_Tables(StatementHandle, ctName, NameLength1,
 				scName, NameLength2, tbName, NameLength3,
 					TableType, NameLength4, flag);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt =NULL, *newSc = NULL, *newTb = NULL;
@@ -1025,8 +1024,7 @@ SQLTransact(HENV EnvironmentHandle,
 }
 
 RETCODE		SQL_API
-SQLColAttributes(
-				 HSTMT hstmt,
+SQLColAttributes(HSTMT hstmt,
 				 SQLUSMALLINT icol,
 				 SQLUSMALLINT fDescType,
 				 PTR rgbDesc,
@@ -1050,8 +1048,7 @@ SQLColAttributes(
 #endif /* ODBCVER */
 
 RETCODE		SQL_API
-SQLColumnPrivileges(
-					HSTMT hstmt,
+SQLColumnPrivileges(HSTMT hstmt,
 					SQLCHAR *szCatalogName,
 					SQLSMALLINT cbCatalogName,
 					SQLCHAR *szSchemaName,
@@ -1082,7 +1079,7 @@ SQLColumnPrivileges(
 		ret = PGAPI_ColumnPrivileges(hstmt, ctName, cbCatalogName,
 				scName, cbSchemaName, tbName, cbTableName,
 						clName, cbColumnName, flag);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newTb = NULL, *newCl = NULL;
@@ -1131,8 +1128,7 @@ SQLColumnPrivileges(
 }
 
 RETCODE		SQL_API
-SQLDescribeParam(
-				 HSTMT hstmt,
+SQLDescribeParam(HSTMT hstmt,
 				 SQLUSMALLINT ipar,
 				 SQLSMALLINT *pfSqlType,
 				 SQLULEN *pcbParamDef,
@@ -1154,8 +1150,7 @@ SQLDescribeParam(
 }
 
 RETCODE		SQL_API
-SQLExtendedFetch(
-				 HSTMT hstmt,
+SQLExtendedFetch(HSTMT hstmt,
 				 SQLUSMALLINT fFetchType,
 				 SQLLEN irow,
 #if defined(WITH_UNIXODBC) && (SIZEOF_LONG != 8)
@@ -1190,8 +1185,7 @@ SQLExtendedFetch(
 }
 
 RETCODE		SQL_API
-SQLForeignKeys(
-			   HSTMT hstmt,
+SQLForeignKeys(HSTMT hstmt,
 			   SQLCHAR *szPkCatalogName,
 			   SQLSMALLINT cbPkCatalogName,
 			   SQLCHAR *szPkSchemaName,
@@ -1223,7 +1217,7 @@ SQLForeignKeys(
 			pkscName, cbPkSchemaName, pktbName, cbPkTableName,
 			fkctName, cbFkCatalogName, fkscName, cbFkSchemaName,
 			fktbName, cbFkTableName);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newPkct = NULL, *newPksc = NULL, *newPktb = NULL,
@@ -1304,8 +1298,7 @@ SQLMoreResults(HSTMT hstmt)
 }
 
 RETCODE		SQL_API
-SQLNativeSql(
-			 HDBC hdbc,
+SQLNativeSql(HDBC hdbc,
 			 SQLCHAR *szSqlStrIn,
 			 SQLINTEGER cbSqlStrIn,
 			 SQLCHAR *szSqlStr,
@@ -1326,8 +1319,7 @@ SQLNativeSql(
 }
 
 RETCODE		SQL_API
-SQLNumParams(
-			 HSTMT hstmt,
+SQLNumParams(HSTMT hstmt,
 			 SQLSMALLINT *pcpar)
 {
 	RETCODE	ret;
@@ -1345,8 +1337,7 @@ SQLNumParams(
 
 #if (ODBCVER < 0x0300)
 RETCODE		SQL_API
-SQLParamOptions(
-				HSTMT hstmt,
+SQLParamOptions(HSTMT hstmt,
 				SQLULEN crow,
 				SQLULEN *pirow)
 {
@@ -1365,8 +1356,7 @@ SQLParamOptions(
 #endif /* ODBCVER */
 
 RETCODE		SQL_API
-SQLPrimaryKeys(
-			   HSTMT hstmt,
+SQLPrimaryKeys(HSTMT hstmt,
 			   SQLCHAR *szCatalogName,
 			   SQLSMALLINT cbCatalogName,
 			   SQLCHAR *szSchemaName,
@@ -1389,7 +1379,7 @@ SQLPrimaryKeys(
 	else
 		ret = PGAPI_PrimaryKeys(hstmt, ctName, cbCatalogName,
 			scName, cbSchemaName, tbName, cbTableName, 0);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newTb = NULL;
@@ -1430,8 +1420,7 @@ SQLPrimaryKeys(
 }
 
 RETCODE		SQL_API
-SQLProcedureColumns(
-					HSTMT hstmt,
+SQLProcedureColumns(HSTMT hstmt,
 					SQLCHAR *szCatalogName,
 					SQLSMALLINT cbCatalogName,
 					SQLCHAR *szSchemaName,
@@ -1462,7 +1451,7 @@ SQLProcedureColumns(
 		ret = PGAPI_ProcedureColumns(hstmt, ctName, cbCatalogName,
 				scName, cbSchemaName, prName, cbProcName,
 					clName, cbColumnName, flag);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newPr = NULL, *newCl = NULL;
@@ -1511,8 +1500,7 @@ SQLProcedureColumns(
 }
 
 RETCODE		SQL_API
-SQLProcedures(
-			  HSTMT hstmt,
+SQLProcedures(HSTMT hstmt,
 			  SQLCHAR *szCatalogName,
 			  SQLSMALLINT cbCatalogName,
 			  SQLCHAR *szSchemaName,
@@ -1541,7 +1529,7 @@ SQLProcedures(
 		ret = PGAPI_Procedures(hstmt, ctName, cbCatalogName,
 					 scName, cbSchemaName, prName,
 					 cbProcName, flag);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newPr = NULL;
@@ -1582,8 +1570,7 @@ SQLProcedures(
 }
 
 RETCODE		SQL_API
-SQLSetPos(
-		  HSTMT hstmt,
+SQLSetPos(HSTMT hstmt,
 		  SQLSETPOSIROW irow,
 		  SQLUSMALLINT fOption,
 		  SQLUSMALLINT fLock)
@@ -1602,8 +1589,7 @@ SQLSetPos(
 }
 
 RETCODE		SQL_API
-SQLTablePrivileges(
-				   HSTMT hstmt,
+SQLTablePrivileges(HSTMT hstmt,
 				   SQLCHAR *szCatalogName,
 				   SQLSMALLINT cbCatalogName,
 				   SQLCHAR *szSchemaName,
@@ -1631,7 +1617,7 @@ SQLTablePrivileges(
 	else
 		ret = PGAPI_TablePrivileges(hstmt, ctName, cbCatalogName,
 			scName, cbSchemaName, tbName, cbTableName, flag);
-	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt)) 
+	if (SQL_SUCCESS == ret && theResultIsEmpty(stmt))
 	{
 		BOOL	ifallupper = TRUE, reexec = FALSE;
 		SQLCHAR *newCt = NULL, *newSc = NULL, *newTb = NULL;
@@ -1672,8 +1658,7 @@ SQLTablePrivileges(
 }
 
 RETCODE		SQL_API
-SQLBindParameter(
-				 HSTMT hstmt,
+SQLBindParameter(HSTMT hstmt,
 				 SQLUSMALLINT ipar,
 				 SQLSMALLINT fParamType,
 				 SQLSMALLINT fCType,
