@@ -6,7 +6,7 @@
  * Classes:			n/a
  *
  * API functions:	SQLColumnPrivilegesW, SQLColumnsW,
- 			SQLConnectW, SQLDataSourcesW, SQLDescribeColW,
+			SQLConnectW, SQLDataSourcesW, SQLDescribeColW,
 			SQLDriverConnectW, SQLExecDirectW,
 			SQLForeignKeysW,
 			SQLGetCursorNameW, SQLGetInfoW, SQLNativeSqlW,
@@ -25,11 +25,12 @@
 #include "connection.h"
 #include "statement.h"
 
-RETCODE  SQL_API SQLColumnsW(HSTMT StatementHandle,
-           SQLWCHAR *CatalogName, SQLSMALLINT NameLength1,
-           SQLWCHAR *SchemaName, SQLSMALLINT NameLength2,
-           SQLWCHAR *TableName, SQLSMALLINT NameLength3,
-           SQLWCHAR *ColumnName, SQLSMALLINT NameLength4)
+RETCODE  SQL_API
+SQLColumnsW(HSTMT StatementHandle,
+			SQLWCHAR *CatalogName, SQLSMALLINT NameLength1,
+			SQLWCHAR *SchemaName, SQLSMALLINT NameLength2,
+			SQLWCHAR *TableName, SQLSMALLINT NameLength3,
+			SQLWCHAR *ColumnName, SQLSMALLINT NameLength4)
 {
 	CSTR func = "SQLColumnsW";
 	RETCODE	ret;
@@ -38,7 +39,7 @@ RETCODE  SQL_API SQLColumnsW(HSTMT StatementHandle,
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 	ConnectionClass *conn;
 	BOOL	lower_id;
-	UWORD	flag = PODBC_SEARCH_PUBLIC_SCHEMA; 
+	UWORD	flag = PODBC_SEARCH_PUBLIC_SCHEMA;
 
 	mylog("[%s]", func);
 	conn = SC_get_conn(stmt);
@@ -57,9 +58,12 @@ RETCODE  SQL_API SQLColumnsW(HSTMT StatementHandle,
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_Columns(StatementHandle, ctName, (SQLSMALLINT) nmlen1,
-           		scName, (SQLSMALLINT) nmlen2, tbName, (SQLSMALLINT) nmlen3,
-           		clName, (SQLSMALLINT) nmlen4, flag, 0, 0);
+		ret = PGAPI_Columns(StatementHandle,
+							(SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+							(SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+							(SQLCHAR *) tbName, (SQLSMALLINT) nmlen3,
+							(SQLCHAR *) clName, (SQLSMALLINT) nmlen4,
+							flag, 0, 0);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (ctName)
@@ -74,17 +78,18 @@ RETCODE  SQL_API SQLColumnsW(HSTMT StatementHandle,
 }
 
 
-RETCODE  SQL_API SQLConnectW(HDBC ConnectionHandle,
-           SQLWCHAR *ServerName, SQLSMALLINT NameLength1,
-           SQLWCHAR *UserName, SQLSMALLINT NameLength2,
-           SQLWCHAR *Authentication, SQLSMALLINT NameLength3)
+RETCODE  SQL_API
+SQLConnectW(HDBC ConnectionHandle,
+			SQLWCHAR *ServerName, SQLSMALLINT NameLength1,
+			SQLWCHAR *UserName, SQLSMALLINT NameLength2,
+			SQLWCHAR *Authentication, SQLSMALLINT NameLength3)
 {
 	CSTR func = "SQLConnectW";
 	char	*svName, *usName, *auth;
 	SQLLEN	nmlen1, nmlen2, nmlen3;
 	RETCODE	ret;
 	ConnectionClass *conn = (ConnectionClass *) ConnectionHandle;
-	
+
 	mylog("[%s]", func);
 	CC_examine_global_transaction(conn);
 	ENTER_CONN_CS(conn);
@@ -93,8 +98,10 @@ RETCODE  SQL_API SQLConnectW(HDBC ConnectionHandle,
 	svName = ucs2_to_utf8(ServerName, NameLength1, &nmlen1, FALSE);
 	usName = ucs2_to_utf8(UserName, NameLength2, &nmlen2, FALSE);
 	auth = ucs2_to_utf8(Authentication, NameLength3, &nmlen3, FALSE);
-	ret = PGAPI_Connect(ConnectionHandle, svName, (SQLSMALLINT) nmlen1,
-           	usName, (SQLSMALLINT) nmlen2, auth, (SQLSMALLINT) nmlen3);
+	ret = PGAPI_Connect(ConnectionHandle,
+						(SQLCHAR *) svName, (SQLSMALLINT) nmlen1,
+						(SQLCHAR *) usName, (SQLSMALLINT) nmlen2,
+						(SQLCHAR *) auth, (SQLSMALLINT) nmlen3);
 	LEAVE_CONN_CS(conn);
 	if (svName)
 		free(svName);
@@ -105,14 +112,15 @@ RETCODE  SQL_API SQLConnectW(HDBC ConnectionHandle,
 	return ret;
 }
 
-RETCODE SQL_API SQLDriverConnectW(HDBC hdbc,
-                                 HWND hwnd,
-                                 SQLWCHAR *szConnStrIn,
-                                 SQLSMALLINT cbConnStrIn,
-                                 SQLWCHAR *szConnStrOut,
-                                 SQLSMALLINT cbConnStrOutMax,
-                                 SQLSMALLINT FAR *pcbConnStrOut,
-                                 SQLUSMALLINT fDriverCompletion)
+RETCODE SQL_API
+SQLDriverConnectW(HDBC hdbc,
+				  HWND hwnd,
+				  SQLWCHAR *szConnStrIn,
+				  SQLSMALLINT cbConnStrIn,
+				  SQLWCHAR *szConnStrOut,
+				  SQLSMALLINT cbConnStrOutMax,
+				  SQLSMALLINT FAR *pcbConnStrOut,
+				  SQLUSMALLINT fDriverCompletion)
 {
 	CSTR func = "SQLDriverConnectW";
 	char	*szIn, *szOut = NULL;
@@ -139,8 +147,10 @@ RETCODE SQL_API SQLDriverConnectW(HDBC hdbc,
 	}
 	else if (pcbConnStrOut)
 		pCSO = &olen;
-	ret = PGAPI_DriverConnect(hdbc, hwnd, szIn, (SQLSMALLINT) inlen,
-		szOut, maxlen, pCSO, fDriverCompletion);
+	ret = PGAPI_DriverConnect(hdbc, hwnd,
+							  (SQLCHAR *) szIn, (SQLSMALLINT) inlen,
+							  (SQLCHAR *) szOut, maxlen,
+							  pCSO, fDriverCompletion);
 	if (ret != SQL_ERROR && NULL != pCSO)
 	{
 		SQLLEN outlen = olen;
@@ -168,13 +178,13 @@ inolog("cbConnstrOutMax=%d pcb=%p\n", cbConnStrOutMax, pcbConnStrOut);
 		free(szIn);
 	return ret;
 }
-RETCODE SQL_API SQLBrowseConnectW(
-    HDBC            hdbc,
-    SQLWCHAR 		  *szConnStrIn,
-    SQLSMALLINT        cbConnStrIn,
-    SQLWCHAR 		  *szConnStrOut,
-    SQLSMALLINT        cbConnStrOutMax,
-    SQLSMALLINT       *pcbConnStrOut)
+RETCODE SQL_API
+SQLBrowseConnectW(HDBC			hdbc,
+				  SQLWCHAR	   *szConnStrIn,
+				  SQLSMALLINT	cbConnStrIn,
+				  SQLWCHAR	   *szConnStrOut,
+				  SQLSMALLINT	cbConnStrOutMax,
+				  SQLSMALLINT  *pcbConnStrOut)
 {
 	CSTR func = "SQLBrowseConnectW";
 	char	*szIn, *szOut;
@@ -192,8 +202,8 @@ RETCODE SQL_API SQLBrowseConnectW(
 	szIn = ucs2_to_utf8(szConnStrIn, cbConnStrIn, &inlen, FALSE);
 	obuflen = cbConnStrOutMax + 1;
 	szOut = malloc(obuflen);
-	ret = PGAPI_BrowseConnect(hdbc, szIn, (SQLSMALLINT) inlen,
-		szOut, cbConnStrOutMax, &olen);
+	ret = PGAPI_BrowseConnect(hdbc, (SQLCHAR *) szIn, (SQLSMALLINT) inlen,
+							  (SQLCHAR *) szOut, cbConnStrOutMax, &olen);
 	LEAVE_CONN_CS(conn);
 	if (ret != SQL_ERROR)
 	{
@@ -207,27 +217,29 @@ RETCODE SQL_API SQLBrowseConnectW(
 	return ret;
 }
 
-RETCODE  SQL_API SQLDataSourcesW(HENV EnvironmentHandle,
-           SQLUSMALLINT Direction, SQLWCHAR *ServerName,
-           SQLSMALLINT BufferLength1, SQLSMALLINT *NameLength1,
-           SQLWCHAR *Description, SQLSMALLINT BufferLength2,
-           SQLSMALLINT *NameLength2)
+RETCODE  SQL_API
+SQLDataSourcesW(HENV EnvironmentHandle,
+				SQLUSMALLINT Direction, SQLWCHAR *ServerName,
+				SQLSMALLINT BufferLength1, SQLSMALLINT *NameLength1,
+				SQLWCHAR *Description, SQLSMALLINT BufferLength2,
+				SQLSMALLINT *NameLength2)
 {
 	CSTR func = "SQLDataSourcesW";
 	mylog("[%s]", func);
 	/*
 	return PGAPI_DataSources(EnvironmentHandle, Direction, ServerName,
-		 BufferLength1, NameLength1, Description, BufferLength2,
-           	NameLength2);
+		BufferLength1, NameLength1, Description, BufferLength2,
+		NameLength2);
 	*/
 	return SQL_ERROR;
 }
 
-RETCODE  SQL_API SQLDescribeColW(HSTMT StatementHandle,
-           SQLUSMALLINT ColumnNumber, SQLWCHAR *ColumnName,
-           SQLSMALLINT BufferLength, SQLSMALLINT *NameLength,
-           SQLSMALLINT *DataType, SQLULEN *ColumnSize,
-           SQLSMALLINT *DecimalDigits, SQLSMALLINT *Nullable)
+RETCODE  SQL_API
+SQLDescribeColW(HSTMT StatementHandle,
+				SQLUSMALLINT ColumnNumber, SQLWCHAR *ColumnName,
+				SQLSMALLINT BufferLength, SQLSMALLINT *NameLength,
+				SQLSMALLINT *DataType, SQLULEN *ColumnSize,
+				SQLSMALLINT *DecimalDigits, SQLSMALLINT *Nullable)
 {
 	CSTR func = "SQLDescribeColW";
 	RETCODE	ret;
@@ -249,7 +261,8 @@ RETCODE  SQL_API SQLDescribeColW(HSTMT StatementHandle,
 	for (;; buflen = nmlen + 1, clName = realloc(clName, buflen))
 	{
 		ret = PGAPI_DescribeCol(StatementHandle, ColumnNumber,
-			clName, buflen, &nmlen, DataType, ColumnSize,
+								(SQLCHAR *) clName, buflen,
+								&nmlen, DataType, ColumnSize,
 			DecimalDigits, Nullable);
 		if (SQL_SUCCESS_WITH_INFO != ret || nmlen < buflen)
 			break;
@@ -271,12 +284,13 @@ RETCODE  SQL_API SQLDescribeColW(HSTMT StatementHandle,
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (clName)
-		free(clName); 
+		free(clName);
 	return ret;
 }
 
-RETCODE  SQL_API SQLExecDirectW(HSTMT StatementHandle,
-           SQLWCHAR *StatementText, SQLINTEGER TextLength)
+RETCODE  SQL_API
+SQLExecDirectW(HSTMT StatementHandle,
+			   SQLWCHAR *StatementText, SQLINTEGER TextLength)
 {
 	CSTR	func = "SQLExecDirectW";
 	RETCODE	ret;
@@ -295,7 +309,8 @@ RETCODE  SQL_API SQLExecDirectW(HSTMT StatementHandle,
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_ExecDirect(StatementHandle, stxt, (SQLINTEGER) slen, flag);
+		ret = PGAPI_ExecDirect(StatementHandle,
+							   (SQLCHAR *) stxt, (SQLINTEGER) slen, flag);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (stxt)
@@ -303,9 +318,10 @@ RETCODE  SQL_API SQLExecDirectW(HSTMT StatementHandle,
 	return ret;
 }
 
-RETCODE  SQL_API SQLGetCursorNameW(HSTMT StatementHandle,
-           SQLWCHAR *CursorName, SQLSMALLINT BufferLength,
-           SQLSMALLINT *NameLength)
+RETCODE  SQL_API
+SQLGetCursorNameW(HSTMT StatementHandle,
+				  SQLWCHAR *CursorName, SQLSMALLINT BufferLength,
+				  SQLSMALLINT *NameLength)
 {
 	CSTR func = "SQLGetCursorNameW";
 	RETCODE	ret;
@@ -324,7 +340,7 @@ RETCODE  SQL_API SQLGetCursorNameW(HSTMT StatementHandle,
 	StartRollbackState(stmt);
 	for (;; buflen = clen + 1, crName = realloc(crName, buflen))
 	{
-		ret = PGAPI_GetCursorName(StatementHandle, crName, buflen, &clen);
+		ret = PGAPI_GetCursorName(StatementHandle, (SQLCHAR *) crName, buflen, &clen);
 		if (SQL_SUCCESS_WITH_INFO != ret || clen < buflen)
 			break;
 	}
@@ -348,9 +364,10 @@ RETCODE  SQL_API SQLGetCursorNameW(HSTMT StatementHandle,
 	return ret;
 }
 
-RETCODE  SQL_API SQLGetInfoW(HDBC ConnectionHandle,
-           SQLUSMALLINT InfoType, PTR InfoValue,
-           SQLSMALLINT BufferLength, SQLSMALLINT *StringLength)
+RETCODE  SQL_API
+SQLGetInfoW(HDBC ConnectionHandle,
+			SQLUSMALLINT InfoType, PTR InfoValue,
+			SQLSMALLINT BufferLength, SQLSMALLINT *StringLength)
 {
 	CSTR func = "SQLGetInfoW";
 	ConnectionClass	*conn = (ConnectionClass *) ConnectionHandle;
@@ -363,13 +380,13 @@ RETCODE  SQL_API SQLGetInfoW(HDBC ConnectionHandle,
 #if (ODBCVER >= 0x0300)
 	mylog("[%s(30)]", func);
 	if ((ret = PGAPI_GetInfo(ConnectionHandle, InfoType, InfoValue,
-           	BufferLength, StringLength)) == SQL_ERROR)
+							 BufferLength, StringLength)) == SQL_ERROR)
 	{
 		if (conn->driver_version >= 0x0300)
 		{
 			CC_clear_error(conn);
 			ret = PGAPI_GetInfo30(ConnectionHandle, InfoType, InfoValue,
-           			BufferLength, StringLength);
+								  BufferLength, StringLength);
 		}
 	}
 	if (SQL_ERROR == ret)
@@ -377,7 +394,7 @@ RETCODE  SQL_API SQLGetInfoW(HDBC ConnectionHandle,
 #else
 	mylog("[%s]", func);
 	ret = PGAPI_GetInfo(ConnectionHandle, InfoType, InfoValue,
-           	BufferLength, StringLength);
+						BufferLength, StringLength);
 	if (SQL_ERROR == ret)
 		CC_log_error("SQLGetInfoW", "", conn);
 #endif
@@ -385,8 +402,9 @@ RETCODE  SQL_API SQLGetInfoW(HDBC ConnectionHandle,
 	return ret;
 }
 
-RETCODE  SQL_API SQLPrepareW(HSTMT StatementHandle,
-           SQLWCHAR *StatementText, SQLINTEGER TextLength)
+RETCODE  SQL_API
+SQLPrepareW(HSTMT StatementHandle,
+			SQLWCHAR *StatementText, SQLINTEGER TextLength)
 {
 	CSTR func = "SQLPrepareW";
 	StatementClass *stmt = (StatementClass *) StatementHandle;
@@ -402,7 +420,7 @@ RETCODE  SQL_API SQLPrepareW(HSTMT StatementHandle,
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_Prepare(StatementHandle, stxt, (SQLINTEGER) slen);
+		ret = PGAPI_Prepare(StatementHandle, (SQLCHAR *) stxt, (SQLINTEGER) slen);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (stxt)
@@ -410,8 +428,9 @@ RETCODE  SQL_API SQLPrepareW(HSTMT StatementHandle,
 	return ret;
 }
 
-RETCODE  SQL_API SQLSetCursorNameW(HSTMT StatementHandle,
-           SQLWCHAR *CursorName, SQLSMALLINT NameLength)
+RETCODE  SQL_API
+SQLSetCursorNameW(HSTMT StatementHandle,
+				  SQLWCHAR *CursorName, SQLSMALLINT NameLength)
 {
 	CSTR func = "SQLSetCursorNameW";
 	RETCODE	ret;
@@ -424,7 +443,7 @@ RETCODE  SQL_API SQLSetCursorNameW(HSTMT StatementHandle,
 	ENTER_STMT_CS(stmt);
 	SC_clear_error(stmt);
 	StartRollbackState(stmt);
-	ret = PGAPI_SetCursorName(StatementHandle, crName, (SQLSMALLINT) nlen);
+	ret = PGAPI_SetCursorName(StatementHandle, (SQLCHAR *) crName, (SQLSMALLINT) nlen);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (crName)
@@ -432,12 +451,13 @@ RETCODE  SQL_API SQLSetCursorNameW(HSTMT StatementHandle,
 	return ret;
 }
 
-RETCODE  SQL_API SQLSpecialColumnsW(HSTMT StatementHandle,
-           SQLUSMALLINT IdentifierType, SQLWCHAR *CatalogName,
-           SQLSMALLINT NameLength1, SQLWCHAR *SchemaName,
-           SQLSMALLINT NameLength2, SQLWCHAR *TableName,
-           SQLSMALLINT NameLength3, SQLUSMALLINT Scope,
-           SQLUSMALLINT Nullable)
+RETCODE  SQL_API
+SQLSpecialColumnsW(HSTMT StatementHandle,
+				   SQLUSMALLINT IdentifierType, SQLWCHAR *CatalogName,
+				   SQLSMALLINT NameLength1, SQLWCHAR *SchemaName,
+				   SQLSMALLINT NameLength2, SQLWCHAR *TableName,
+				   SQLSMALLINT NameLength3, SQLUSMALLINT Scope,
+				   SQLUSMALLINT Nullable)
 {
 	CSTR func = "SQLSpecialColumnsW";
 	RETCODE	ret;
@@ -446,7 +466,7 @@ RETCODE  SQL_API SQLSpecialColumnsW(HSTMT StatementHandle,
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 	ConnectionClass *conn;
 	BOOL lower_id;
-	
+
 	mylog("[%s]", func);
 	conn = SC_get_conn(stmt);
 	lower_id = SC_is_lower_case(stmt, conn);
@@ -459,9 +479,11 @@ RETCODE  SQL_API SQLSpecialColumnsW(HSTMT StatementHandle,
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_SpecialColumns(StatementHandle, IdentifierType, ctName,
-           	(SQLSMALLINT) nmlen1, scName, (SQLSMALLINT) nmlen2, tbName, (SQLSMALLINT) nmlen3,
-		Scope, Nullable);
+		ret = PGAPI_SpecialColumns(StatementHandle, IdentifierType,
+								   (SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+								   (SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+								   (SQLCHAR *) tbName, (SQLSMALLINT) nmlen3,
+								   Scope, Nullable);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (ctName)
@@ -473,11 +495,12 @@ RETCODE  SQL_API SQLSpecialColumnsW(HSTMT StatementHandle,
 	return ret;
 }
 
-RETCODE  SQL_API SQLStatisticsW(HSTMT StatementHandle,
-           SQLWCHAR *CatalogName, SQLSMALLINT NameLength1,
-           SQLWCHAR *SchemaName, SQLSMALLINT NameLength2,
-           SQLWCHAR *TableName, SQLSMALLINT NameLength3,
-           SQLUSMALLINT Unique, SQLUSMALLINT Reserved)
+RETCODE  SQL_API
+SQLStatisticsW(HSTMT StatementHandle,
+			   SQLWCHAR *CatalogName, SQLSMALLINT NameLength1,
+			   SQLWCHAR *SchemaName, SQLSMALLINT NameLength2,
+			   SQLWCHAR *TableName, SQLSMALLINT NameLength3,
+			   SQLUSMALLINT Unique, SQLUSMALLINT Reserved)
 {
 	CSTR func = "SQLStatisticsW";
 	RETCODE	ret;
@@ -499,9 +522,11 @@ RETCODE  SQL_API SQLStatisticsW(HSTMT StatementHandle,
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_Statistics(StatementHandle, ctName, (SQLSMALLINT) nmlen1,
-           scName, (SQLSMALLINT) nmlen2, tbName, (SQLSMALLINT) nmlen3, Unique,
-		Reserved);
+		ret = PGAPI_Statistics(StatementHandle,
+							   (SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+							   (SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+							   (SQLCHAR *) tbName, (SQLSMALLINT) nmlen3,
+							   Unique, Reserved);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (ctName)
@@ -513,7 +538,8 @@ RETCODE  SQL_API SQLStatisticsW(HSTMT StatementHandle,
 	return ret;
 }
 
-RETCODE  SQL_API SQLTablesW(HSTMT StatementHandle,
+RETCODE  SQL_API
+SQLTablesW(HSTMT StatementHandle,
            SQLWCHAR *CatalogName, SQLSMALLINT NameLength1,
            SQLWCHAR *SchemaName, SQLSMALLINT NameLength2,
            SQLWCHAR *TableName, SQLSMALLINT NameLength3,
@@ -545,9 +571,11 @@ RETCODE  SQL_API SQLTablesW(HSTMT StatementHandle,
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_Tables(StatementHandle, ctName, (SQLSMALLINT) nmlen1,
-           		scName, (SQLSMALLINT) nmlen2, tbName, (SQLSMALLINT) nmlen3,
-           		tbType, (SQLSMALLINT) nmlen4, flag);
+		ret = PGAPI_Tables(StatementHandle,
+						   (SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+						   (SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+						   (SQLCHAR *) tbName, (SQLSMALLINT) nmlen3,
+						   (SQLCHAR *) tbType, (SQLSMALLINT) nmlen4, flag);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (ctName)
@@ -561,16 +589,16 @@ RETCODE  SQL_API SQLTablesW(HSTMT StatementHandle,
 	return ret;
 }
 
-RETCODE SQL_API SQLColumnPrivilegesW(
-    HSTMT           hstmt,
-    SQLWCHAR 		  *szCatalogName,
-    SQLSMALLINT        cbCatalogName,
-    SQLWCHAR 		  *szSchemaName,
-    SQLSMALLINT        cbSchemaName,
-    SQLWCHAR 		  *szTableName,
-    SQLSMALLINT        cbTableName,
-    SQLWCHAR 		  *szColumnName,
-    SQLSMALLINT        cbColumnName)
+RETCODE SQL_API
+SQLColumnPrivilegesW(HSTMT			hstmt,
+					 SQLWCHAR	   *szCatalogName,
+					 SQLSMALLINT	cbCatalogName,
+					 SQLWCHAR	   *szSchemaName,
+					 SQLSMALLINT	cbSchemaName,
+					 SQLWCHAR	   *szTableName,
+					 SQLSMALLINT	cbTableName,
+					 SQLWCHAR	   *szColumnName,
+					 SQLSMALLINT	cbColumnName)
 {
 	CSTR func = "SQLColumnPrivilegesW";
 	RETCODE	ret;
@@ -579,7 +607,7 @@ RETCODE SQL_API SQLColumnPrivilegesW(
 	StatementClass *stmt = (StatementClass *) hstmt;
 	ConnectionClass *conn;
 	BOOL	lower_id;
-	UWORD	flag = 0; 
+	UWORD	flag = 0;
 
 	mylog("[%s]", func);
 	conn = SC_get_conn(stmt);
@@ -598,9 +626,12 @@ RETCODE SQL_API SQLColumnPrivilegesW(
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_ColumnPrivileges(hstmt, ctName, (SQLSMALLINT) nmlen1,
-			scName, (SQLSMALLINT) nmlen2, tbName, (SQLSMALLINT) nmlen3,
-			clName, (SQLSMALLINT) nmlen4, flag);
+		ret = PGAPI_ColumnPrivileges(hstmt,
+									 (SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+									 (SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+									 (SQLCHAR *) tbName, (SQLSMALLINT) nmlen3,
+									 (SQLCHAR *) clName, (SQLSMALLINT) nmlen4,
+									 flag);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (ctName)
@@ -614,20 +645,20 @@ RETCODE SQL_API SQLColumnPrivilegesW(
 	return ret;
 }
 
-RETCODE SQL_API SQLForeignKeysW(
-    HSTMT           hstmt,
-    SQLWCHAR 		  *szPkCatalogName,
-    SQLSMALLINT        cbPkCatalogName,
-    SQLWCHAR 		  *szPkSchemaName,
-    SQLSMALLINT        cbPkSchemaName,
-    SQLWCHAR 		  *szPkTableName,
-    SQLSMALLINT        cbPkTableName,
-    SQLWCHAR 		  *szFkCatalogName,
-    SQLSMALLINT        cbFkCatalogName,
-    SQLWCHAR 		  *szFkSchemaName,
-    SQLSMALLINT        cbFkSchemaName,
-    SQLWCHAR 		  *szFkTableName,
-    SQLSMALLINT        cbFkTableName)
+RETCODE SQL_API
+SQLForeignKeysW(HSTMT			hstmt,
+				SQLWCHAR	   *szPkCatalogName,
+				SQLSMALLINT		cbPkCatalogName,
+				SQLWCHAR	   *szPkSchemaName,
+				SQLSMALLINT		cbPkSchemaName,
+				SQLWCHAR	   *szPkTableName,
+				SQLSMALLINT		cbPkTableName,
+				SQLWCHAR	   *szFkCatalogName,
+				SQLSMALLINT		cbFkCatalogName,
+				SQLWCHAR	   *szFkSchemaName,
+				SQLSMALLINT		cbFkSchemaName,
+				SQLWCHAR	   *szFkTableName,
+				SQLSMALLINT		cbFkTableName)
 {
 	CSTR func = "SQLForeignKeysW";
 	RETCODE	ret;
@@ -635,7 +666,7 @@ RETCODE SQL_API SQLForeignKeysW(
 	SQLLEN	nmlen1, nmlen2, nmlen3, nmlen4, nmlen5, nmlen6;
 	StatementClass *stmt = (StatementClass *) hstmt;
 	ConnectionClass *conn;
-	BOOL	lower_id; 
+	BOOL	lower_id;
 
 	mylog("[%s]", func);
 	conn = SC_get_conn(stmt);
@@ -652,10 +683,13 @@ RETCODE SQL_API SQLForeignKeysW(
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_ForeignKeys(hstmt, ctName, (SQLSMALLINT) nmlen1,
-			scName, (SQLSMALLINT) nmlen2, tbName, (SQLSMALLINT) nmlen3,
-			fkctName, (SQLSMALLINT) nmlen4, fkscName, (SQLSMALLINT) nmlen5,
-			fktbName, (SQLSMALLINT) nmlen6);
+		ret = PGAPI_ForeignKeys(hstmt,
+								(SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+								(SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+								(SQLCHAR *) tbName, (SQLSMALLINT) nmlen3,
+								(SQLCHAR *) fkctName, (SQLSMALLINT) nmlen4,
+								(SQLCHAR *) fkscName, (SQLSMALLINT) nmlen5,
+								(SQLCHAR *) fktbName, (SQLSMALLINT) nmlen6);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (ctName)
@@ -673,13 +707,13 @@ RETCODE SQL_API SQLForeignKeysW(
 	return ret;
 }
 
-RETCODE SQL_API SQLNativeSqlW(
-    HDBC            hdbc,
-    SQLWCHAR 		  *szSqlStrIn,
-    SQLINTEGER         cbSqlStrIn,
-    SQLWCHAR 		  *szSqlStr,
-    SQLINTEGER         cbSqlStrMax,
-    SQLINTEGER 		  *pcbSqlStr)
+RETCODE SQL_API
+SQLNativeSqlW(HDBC			hdbc,
+			  SQLWCHAR	   *szSqlStrIn,
+			  SQLINTEGER	cbSqlStrIn,
+			  SQLWCHAR	   *szSqlStr,
+			  SQLINTEGER	cbSqlStrMax,
+			  SQLINTEGER   *pcbSqlStr)
 {
 	CSTR func = "SQLNativeSqlW";
 	RETCODE		ret;
@@ -699,8 +733,8 @@ RETCODE SQL_API SQLNativeSqlW(
 		szOut = malloc(buflen);
 	for (;; buflen = olen + 1, szOut = realloc(szOut, buflen))
 	{
-		ret = PGAPI_NativeSql(hdbc, szIn, (SQLINTEGER) slen,
-			szOut, buflen, &olen);
+		ret = PGAPI_NativeSql(hdbc, (SQLCHAR *) szIn, (SQLINTEGER) slen,
+							  (SQLCHAR *) szOut, buflen, &olen);
 		if (SQL_SUCCESS_WITH_INFO != ret || olen < buflen)
 			break;
 	}
@@ -727,14 +761,14 @@ RETCODE SQL_API SQLNativeSqlW(
 	return ret;
 }
 
-RETCODE SQL_API SQLPrimaryKeysW(
-    HSTMT           hstmt,
-    SQLWCHAR 		  *szCatalogName,
-    SQLSMALLINT        cbCatalogName,
-    SQLWCHAR 		  *szSchemaName,
-    SQLSMALLINT        cbSchemaName,
-    SQLWCHAR 		  *szTableName,
-    SQLSMALLINT        cbTableName)
+RETCODE SQL_API
+SQLPrimaryKeysW(HSTMT			hstmt,
+				SQLWCHAR	   *szCatalogName,
+				SQLSMALLINT		cbCatalogName,
+				SQLWCHAR	   *szSchemaName,
+				SQLSMALLINT		cbSchemaName,
+				SQLWCHAR	   *szTableName,
+				SQLSMALLINT		cbTableName)
 {
 	CSTR func = "SQLPrimaryKeysW";
 	RETCODE	ret;
@@ -742,7 +776,7 @@ RETCODE SQL_API SQLPrimaryKeysW(
 	SQLLEN	nmlen1, nmlen2, nmlen3;
 	StatementClass *stmt = (StatementClass *) hstmt;
 	ConnectionClass *conn;
-	BOOL	lower_id; 
+	BOOL	lower_id;
 
 	mylog("[%s]", func);
 	conn = SC_get_conn(stmt);
@@ -756,8 +790,10 @@ RETCODE SQL_API SQLPrimaryKeysW(
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_PrimaryKeys(hstmt, ctName, (SQLSMALLINT) nmlen1,
-			scName, (SQLSMALLINT) nmlen2, tbName, (SQLSMALLINT) nmlen3, 0);
+		ret = PGAPI_PrimaryKeys(hstmt,
+								(SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+								(SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+								(SQLCHAR *) tbName, (SQLSMALLINT) nmlen3, 0);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (ctName)
@@ -769,16 +805,16 @@ RETCODE SQL_API SQLPrimaryKeysW(
 	return ret;
 }
 
-RETCODE SQL_API SQLProcedureColumnsW(
-    HSTMT           hstmt,
-    SQLWCHAR 		  *szCatalogName,
-    SQLSMALLINT        cbCatalogName,
-    SQLWCHAR 		  *szSchemaName,
-    SQLSMALLINT        cbSchemaName,
-    SQLWCHAR 		  *szProcName,
-    SQLSMALLINT        cbProcName,
-    SQLWCHAR 		  *szColumnName,
-    SQLSMALLINT        cbColumnName)
+RETCODE SQL_API
+SQLProcedureColumnsW(HSTMT			hstmt,
+					 SQLWCHAR	   *szCatalogName,
+					 SQLSMALLINT	cbCatalogName,
+					 SQLWCHAR	   *szSchemaName,
+					 SQLSMALLINT	cbSchemaName,
+					 SQLWCHAR	   *szProcName,
+					 SQLSMALLINT	cbProcName,
+					 SQLWCHAR	   *szColumnName,
+					 SQLSMALLINT	cbColumnName)
 {
 	CSTR func = "SQLProcedureColumnsW";
 	RETCODE	ret;
@@ -787,7 +823,7 @@ RETCODE SQL_API SQLProcedureColumnsW(
 	StatementClass *stmt = (StatementClass *) hstmt;
 	ConnectionClass *conn;
 	BOOL	lower_id;
-	UWORD	flag = 0; 
+	UWORD	flag = 0;
 
 	mylog("[%s]", func);
 	conn = SC_get_conn(stmt);
@@ -806,9 +842,12 @@ RETCODE SQL_API SQLProcedureColumnsW(
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_ProcedureColumns(hstmt, ctName, (SQLSMALLINT) nmlen1,
-			scName, (SQLSMALLINT) nmlen2, prName, (SQLSMALLINT) nmlen3,
-			clName, (SQLSMALLINT) nmlen4, flag);
+		ret = PGAPI_ProcedureColumns(hstmt,
+									 (SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+									 (SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+									 (SQLCHAR *) prName, (SQLSMALLINT) nmlen3,
+									 (SQLCHAR *) clName, (SQLSMALLINT) nmlen4,
+									 flag);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (ctName)
@@ -822,14 +861,14 @@ RETCODE SQL_API SQLProcedureColumnsW(
 	return ret;
 }
 
-RETCODE SQL_API SQLProceduresW(
-    HSTMT           hstmt,
-    SQLWCHAR 		  *szCatalogName,
-    SQLSMALLINT        cbCatalogName,
-    SQLWCHAR 		  *szSchemaName,
-    SQLSMALLINT        cbSchemaName,
-    SQLWCHAR 		  *szProcName,
-    SQLSMALLINT        cbProcName)
+RETCODE SQL_API
+SQLProceduresW(HSTMT		hstmt,
+			   SQLWCHAR	   *szCatalogName,
+			   SQLSMALLINT	cbCatalogName,
+			   SQLWCHAR	   *szSchemaName,
+			   SQLSMALLINT	cbSchemaName,
+			   SQLWCHAR	   *szProcName,
+			   SQLSMALLINT	cbProcName)
 {
 	CSTR func = "SQLProceduresW";
 	RETCODE	ret;
@@ -838,7 +877,7 @@ RETCODE SQL_API SQLProceduresW(
 	StatementClass *stmt = (StatementClass *) hstmt;
 	ConnectionClass *conn;
 	BOOL	lower_id;
-	UWORD	flag = 0; 
+	UWORD	flag = 0;
 
 	mylog("[%s]", func);
 	conn = SC_get_conn(stmt);
@@ -856,9 +895,11 @@ RETCODE SQL_API SQLProceduresW(
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_Procedures(hstmt, ctName, (SQLSMALLINT) nmlen1,
-					scName, (SQLSMALLINT) nmlen2, prName,
-					 (SQLSMALLINT) nmlen3, flag);
+		ret = PGAPI_Procedures(hstmt,
+							   (SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+							   (SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+							   (SQLCHAR *) prName, (SQLSMALLINT) nmlen3,
+							   flag);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS(stmt);
 	if (ctName)
@@ -870,14 +911,14 @@ RETCODE SQL_API SQLProceduresW(
 	return ret;
 }
 
-RETCODE SQL_API SQLTablePrivilegesW(
-    HSTMT           hstmt,
-    SQLWCHAR 		  *szCatalogName,
-    SQLSMALLINT        cbCatalogName,
-    SQLWCHAR 		  *szSchemaName,
-    SQLSMALLINT        cbSchemaName,
-    SQLWCHAR 		  *szTableName,
-    SQLSMALLINT        cbTableName)
+RETCODE SQL_API
+SQLTablePrivilegesW(HSTMT			hstmt,
+					SQLWCHAR	   *szCatalogName,
+					SQLSMALLINT		cbCatalogName,
+					SQLWCHAR	   *szSchemaName,
+					SQLSMALLINT		cbSchemaName,
+					SQLWCHAR	   *szTableName,
+					SQLSMALLINT		cbTableName)
 {
 	CSTR func = "SQLTablePrivilegesW";
 	RETCODE	ret;
@@ -885,8 +926,8 @@ RETCODE SQL_API SQLTablePrivilegesW(
 	SQLLEN	nmlen1, nmlen2, nmlen3;
 	StatementClass *stmt = (StatementClass *) hstmt;
 	ConnectionClass *conn;
-	BOOL	lower_id; 
-	UWORD	flag = 0; 
+	BOOL	lower_id;
+	UWORD	flag = 0;
 
 	mylog("[%s]", func);
 	conn = SC_get_conn(stmt);
@@ -904,8 +945,11 @@ RETCODE SQL_API SQLTablePrivilegesW(
 	if (SC_opencheck(stmt, func))
 		ret = SQL_ERROR;
 	else
-		ret = PGAPI_TablePrivileges(hstmt, ctName, (SQLSMALLINT) nmlen1,
-			scName, (SQLSMALLINT) nmlen2, tbName, (SQLSMALLINT) nmlen3, flag);
+		ret = PGAPI_TablePrivileges(hstmt,
+									(SQLCHAR *) ctName, (SQLSMALLINT) nmlen1,
+									(SQLCHAR *) scName, (SQLSMALLINT) nmlen2,
+									(SQLCHAR *) tbName, (SQLSMALLINT) nmlen3,
+									flag);
 	ret = DiscardStatementSvp(stmt, ret, FALSE);
 	LEAVE_STMT_CS((StatementClass *) hstmt);
 	if (ctName)
@@ -917,9 +961,9 @@ RETCODE SQL_API SQLTablePrivilegesW(
 	return ret;
 }
 
-RETCODE SQL_API	SQLGetTypeInfoW(
-		SQLHSTMT	StatementHandle,
-		SQLSMALLINT	DataType)
+RETCODE SQL_API
+SQLGetTypeInfoW(SQLHSTMT	StatementHandle,
+				SQLSMALLINT	DataType)
 {
 	CSTR func = "SQLGetTypeInfoW";
 	RETCODE	ret;
