@@ -33,9 +33,9 @@
 /*	SQLError -> SQLDiagRec */
 RETCODE		SQL_API
 PGAPI_GetDiagRec(SQLSMALLINT HandleType, SQLHANDLE Handle,
-		SQLSMALLINT RecNumber, SQLCHAR *Sqlstate,
-		SQLINTEGER *NativeError, SQLCHAR *MessageText,
-		SQLSMALLINT BufferLength, SQLSMALLINT *TextLength)
+				 SQLSMALLINT RecNumber, SQLCHAR *Sqlstate,
+				 SQLINTEGER *NativeError, SQLCHAR *MessageText,
+				 SQLSMALLINT BufferLength, SQLSMALLINT *TextLength)
 {
 	RETCODE		ret;
 	CSTR func = "PGAPI_GetDiagRec";
@@ -72,14 +72,14 @@ PGAPI_GetDiagRec(SQLSMALLINT HandleType, SQLHANDLE Handle,
 }
 
 /*
- *	Minimal implementation. 
+ *	Minimal implementation.
  *
  */
 RETCODE		SQL_API
 PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
-		SQLSMALLINT RecNumber, SQLSMALLINT DiagIdentifier,
-		PTR DiagInfoPtr, SQLSMALLINT BufferLength,
-		SQLSMALLINT *StringLengthPtr)
+				   SQLSMALLINT RecNumber, SQLSMALLINT DiagIdentifier,
+				   PTR DiagInfoPtr, SQLSMALLINT BufferLength,
+				   SQLSMALLINT *StringLengthPtr)
 {
 	RETCODE		ret = SQL_ERROR, rtn;
 	ConnectionClass	*conn;
@@ -111,20 +111,20 @@ PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
 					break;
 				case SQL_DIAG_MESSAGE_TEXT:
 					ret = PGAPI_EnvError(Handle, RecNumber,
-                        			NULL, NULL, DiagInfoPtr,
-						BufferLength, StringLengthPtr, 0);  
+										 NULL, NULL, DiagInfoPtr,
+										 BufferLength, StringLengthPtr, 0);
 					break;
 				case SQL_DIAG_NATIVE:
 					rtnctype = SQL_C_LONG;
 					ret = PGAPI_EnvError(Handle, RecNumber,
-                        			NULL, (SQLINTEGER *) DiagInfoPtr, NULL,
-						0, NULL, 0);  
+										 NULL, (SQLINTEGER *) DiagInfoPtr, NULL,
+										 0, NULL, 0);
 					break;
 				case SQL_DIAG_NUMBER:
 					rtnctype = SQL_C_LONG;
 					ret = PGAPI_EnvError(Handle, RecNumber,
-                        			NULL, NULL, NULL,
-						0, NULL, 0);
+										 NULL, NULL, NULL,
+										 0, NULL, 0);
 					if (SQL_SUCCEEDED(ret))
 					{
 						*((SQLINTEGER *) DiagInfoPtr) = 1;
@@ -133,9 +133,9 @@ PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
 				case SQL_DIAG_SQLSTATE:
 					rtnlen = 5;
 					ret = PGAPI_EnvError(Handle, RecNumber,
-                        			DiagInfoPtr, NULL, NULL,
-						0, NULL, 0);
-					if (SQL_SUCCESS_WITH_INFO == ret)  
+										 DiagInfoPtr, NULL, NULL,
+										 0, NULL, 0);
+					if (SQL_SUCCESS_WITH_INFO == ret)
 						ret = SQL_SUCCESS;
 					break;
 				case SQL_DIAG_RETURNCODE: /* driver manager returns */
@@ -168,7 +168,7 @@ PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
 					rtnlen = strlen(CC_get_DSN(conn));
 					if (DiagInfoPtr)
 					{
-						strncpy_null((SQLCHAR *) DiagInfoPtr, CC_get_DSN(conn), BufferLength);
+						strncpy_null(DiagInfoPtr, CC_get_DSN(conn), BufferLength);
 						ret = (BufferLength > rtnlen ? SQL_SUCCESS : SQL_SUCCESS_WITH_INFO);
 					}
 					else
@@ -176,31 +176,31 @@ PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
 					break;
 				case SQL_DIAG_MESSAGE_TEXT:
 					ret = PGAPI_ConnectError(Handle, RecNumber,
-                        			NULL, NULL, DiagInfoPtr,
-						BufferLength, StringLengthPtr, 0);  
+											 NULL, NULL, DiagInfoPtr,
+											 BufferLength, StringLengthPtr, 0);
 					break;
 				case SQL_DIAG_NATIVE:
 					rtnctype = SQL_C_LONG;
 					ret = PGAPI_ConnectError(Handle, RecNumber,
-                        			NULL, (SQLINTEGER *) DiagInfoPtr, NULL,
-						0, NULL, 0);  
+											 NULL, (SQLINTEGER *) DiagInfoPtr, NULL,
+											 0, NULL, 0);
 					break;
 				case SQL_DIAG_NUMBER:
 					rtnctype = SQL_C_LONG;
 					ret = PGAPI_ConnectError(Handle, RecNumber,
-                        			NULL, NULL, NULL,
-						0, NULL, 0);
+											 NULL, NULL, NULL,
+											 0, NULL, 0);
 					if (SQL_SUCCEEDED(ret))
 					{
 						*((SQLINTEGER *) DiagInfoPtr) = 1;
 					}
-					break;  
+					break;
 				case SQL_DIAG_SQLSTATE:
 					rtnlen = 5;
 					ret = PGAPI_ConnectError(Handle, RecNumber,
-                        			DiagInfoPtr, NULL, NULL,
-						0, NULL, 0);
-					if (SQL_SUCCESS_WITH_INFO == ret)  
+											 DiagInfoPtr, NULL, NULL,
+											 0, NULL, 0);
+					if (SQL_SUCCESS_WITH_INFO == ret)
 						ret = SQL_SUCCESS;
 					break;
 				case SQL_DIAG_RETURNCODE: /* driver manager returns */
@@ -233,7 +233,7 @@ PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
 					rtnlen = strlen(CC_get_DSN(conn));
 					if (DiagInfoPtr)
 					{
-						strncpy_null((SQLCHAR *) DiagInfoPtr, CC_get_DSN(conn), BufferLength);
+						strncpy_null(DiagInfoPtr, CC_get_DSN(conn), BufferLength);
 						ret = (BufferLength > rtnlen ? SQL_SUCCESS : SQL_SUCCESS_WITH_INFO);
 					}
 					else
@@ -241,14 +241,14 @@ PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
 					break;
 				case SQL_DIAG_MESSAGE_TEXT:
 					ret = PGAPI_StmtError(Handle, RecNumber,
-                        			NULL, NULL, DiagInfoPtr,
-						BufferLength, StringLengthPtr, 0);  
+										  NULL, NULL, DiagInfoPtr,
+										  BufferLength, StringLengthPtr, 0);
 					break;
 				case SQL_DIAG_NATIVE:
 					rtnctype = SQL_C_LONG;
 					ret = PGAPI_StmtError(Handle, RecNumber,
-                        			NULL, (SQLINTEGER *) DiagInfoPtr, NULL,
-						0, NULL, 0);  
+										  NULL, (SQLINTEGER *) DiagInfoPtr, NULL,
+										  0, NULL, 0);
 					break;
 				case SQL_DIAG_NUMBER:
 					rtnctype = SQL_C_LONG;
@@ -273,9 +273,9 @@ PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
 				case SQL_DIAG_SQLSTATE:
 					rtnlen = 5;
 					ret = PGAPI_StmtError(Handle, RecNumber,
-                        			DiagInfoPtr, NULL, NULL,
-						0, NULL, 0);
-					if (SQL_SUCCESS_WITH_INFO == ret)  
+										  DiagInfoPtr, NULL, NULL,
+										  0, NULL, 0);
+					if (SQL_SUCCESS_WITH_INFO == ret)
 						ret = SQL_SUCCESS;
 					break;
 				case SQL_DIAG_CURSOR_ROW_COUNT:
@@ -292,7 +292,7 @@ PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
 							rc = 0;
 						else if (res && QR_NumResultCols(res) > 0 && !SC_is_fetchcursor(stmt))
 							rc = QR_get_num_total_tuples(res) - res->dl_count;
-					} 
+					}
 					*((SQLLEN *) DiagInfoPtr) = rc;
 inolog("rc=%d\n", rc);
 					ret = SQL_SUCCESS;
@@ -318,7 +318,7 @@ inolog("rc=%d\n", rc);
 			}
 			break;
 		case SQL_HANDLE_DESC:
-			conn = DC_get_conn(((DescriptorClass *) Handle)); 
+			conn = DC_get_conn(((DescriptorClass *) Handle));
 			switch (DiagIdentifier)
 			{
 				case SQL_DIAG_CLASS_ORIGIN:
@@ -337,7 +337,7 @@ inolog("rc=%d\n", rc);
 					rtnlen = strlen(CC_get_DSN(conn));
 					if (DiagInfoPtr)
 					{
-						strncpy_null((SQLCHAR *) DiagInfoPtr, CC_get_DSN(conn), BufferLength);
+						strncpy_null(DiagInfoPtr, CC_get_DSN(conn), BufferLength);
 						ret = (BufferLength > rtnlen ? SQL_SUCCESS : SQL_SUCCESS_WITH_INFO);
 					}
 					else
@@ -350,9 +350,9 @@ inolog("rc=%d\n", rc);
 				case SQL_DIAG_SQLSTATE:
 					rtnlen = 5;
 					ret = PGAPI_DescError(Handle, RecNumber,
-                        			DiagInfoPtr, NULL, NULL,
-						0, NULL, 0);
-					if (SQL_SUCCESS_WITH_INFO == ret)  
+										  DiagInfoPtr, NULL, NULL,
+										  0, NULL, 0);
+					if (SQL_SUCCESS_WITH_INFO == ret)
 						ret = SQL_SUCCESS;
 					break;
 				case SQL_DIAG_RETURNCODE: /* driver manager returns */
@@ -373,7 +373,7 @@ inolog("rc=%d\n", rc);
 	{
 		if (SQL_SUCCESS_WITH_INFO == ret)
 			ret = SQL_SUCCESS;
-		if (StringLengthPtr)  
+		if (StringLengthPtr)
 			*StringLengthPtr = sizeof(SQLINTEGER);
 	}
 	else if (rtnlen >= 0)
@@ -385,7 +385,7 @@ inolog("rc=%d\n", rc);
 			if (BufferLength > 0)
 				((char *) DiagInfoPtr) [BufferLength - 1] = '\0';
 		}
-		if (StringLengthPtr)  
+		if (StringLengthPtr)
 			*StringLengthPtr = (SQLSMALLINT) rtnlen;
 	}
 	mylog("%s exiting %d\n", func, ret);
@@ -395,8 +395,8 @@ inolog("rc=%d\n", rc);
 /*	SQLGetConnectOption -> SQLGetconnectAttr */
 RETCODE		SQL_API
 PGAPI_GetConnectAttr(HDBC ConnectionHandle,
-			SQLINTEGER Attribute, PTR Value,
-			SQLINTEGER BufferLength, SQLINTEGER *StringLength)
+					 SQLINTEGER Attribute, PTR Value,
+					 SQLINTEGER BufferLength, SQLINTEGER *StringLength)
 {
 	ConnectionClass *conn = (ConnectionClass *) ConnectionHandle;
 	RETCODE	ret = SQL_SUCCESS;
@@ -429,7 +429,7 @@ PGAPI_GetConnectAttr(HDBC ConnectionHandle,
 }
 
 static SQLHDESC
-descHandleFromStatementHandle(HSTMT StatementHandle, SQLINTEGER descType) 
+descHandleFromStatementHandle(HSTMT StatementHandle, SQLINTEGER descType)
 {
 	StatementClass	*stmt = (StatementClass *) StatementHandle;
 
@@ -472,7 +472,7 @@ static  void column_bindings_set(ARDFields *opts, int cols, BOOL maxset)
 
 static RETCODE SQL_API
 ARDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
-		SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength)
+			SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength)
 {
 	RETCODE		ret = SQL_SUCCESS;
 	ARDFields	*opts = (ARDFields *) (desc + 1);
@@ -483,7 +483,7 @@ ARDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 	{
 		case SQL_DESC_ARRAY_SIZE:
 			opts->size_of_rowset = CAST_UPTR(SQLULEN, Value);
-			return ret; 
+			return ret;
 		case SQL_DESC_ARRAY_STATUS_PTR:
 			opts->row_operation_ptr = Value;
 			return ret;
@@ -587,7 +587,7 @@ ARDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 		case SQL_DESC_NUM_PREC_RADIX:
 		default:ret = SQL_ERROR;
 			DC_set_error(desc, DESC_INVALID_DESCRIPTOR_IDENTIFIER,
-				"invalid descriptor identifier"); 
+				"invalid descriptor identifier");
 	}
 	if (unbind)
 		opts->bindings[row_idx].buffer = NULL;
@@ -642,7 +642,7 @@ static  void parameter_ibindings_set(IPDFields *opts, int params, BOOL maxset)
 
 static RETCODE SQL_API
 APDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
-		SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength)
+			SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength)
 {
 	CSTR		func = "APDSetField";
 	RETCODE		ret = SQL_SUCCESS;
@@ -654,7 +654,7 @@ APDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 	{
 		case SQL_DESC_ARRAY_SIZE:
 			opts->paramset_size = CAST_UPTR(SQLUINTEGER, Value);
-			return ret; 
+			return ret;
 		case SQL_DESC_ARRAY_STATUS_PTR:
 			opts->param_operation_ptr = Value;
 			return ret;
@@ -666,7 +666,7 @@ APDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 			return ret;
 		case SQL_DESC_COUNT:
 			parameter_bindings_set(opts, CAST_PTR(SQLSMALLINT, Value), FALSE);
-			return ret; 
+			return ret;
 
 		case SQL_DESC_TYPE:
 		case SQL_DESC_DATETIME_INTERVAL_CODE:
@@ -689,7 +689,7 @@ inolog("%s RecN=%d allocated=%d\n", func, RecNumber, opts->allocated);
 				"bad parameter number");
 		return SQL_ERROR;*/
 	}
-	para_idx = RecNumber - 1; 
+	para_idx = RecNumber - 1;
 	switch (FieldIdentifier)
 	{
 		case SQL_DESC_TYPE:
@@ -747,7 +747,7 @@ inolog("%s RecN=%d allocated=%d\n", func, RecNumber, opts->allocated);
 		case SQL_DESC_NUM_PREC_RADIX:
 		default:ret = SQL_ERROR;
 			DC_set_error(desc, DESC_INVALID_DESCRIPTOR_IDENTIFIER,
-				"invaid descriptor identifier"); 
+				"invaid descriptor identifier");
 	}
 	if (unbind)
 		opts->parameters[para_idx].buffer = NULL;
@@ -757,7 +757,7 @@ inolog("%s RecN=%d allocated=%d\n", func, RecNumber, opts->allocated);
 
 static RETCODE SQL_API
 IRDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
-		SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength)
+			SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength)
 {
 	RETCODE		ret = SQL_SUCCESS;
 	IRDFields	*opts = (IRDFields *) (desc + 1);
@@ -806,14 +806,14 @@ IRDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 		case SQL_DESC_UPDATABLE: /* read-only */
 		default:ret = SQL_ERROR;
 			DC_set_error(desc, DESC_INVALID_DESCRIPTOR_IDENTIFIER,
-				"invalid descriptor identifier"); 
+				"invalid descriptor identifier");
 	}
 	return ret;
 }
 
 static RETCODE SQL_API
 IPDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
-		SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength)
+			SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength)
 {
 	RETCODE		ret = SQL_SUCCESS;
 	IPDFields	*ipdopts = (IPDFields *) (desc + 1);
@@ -825,12 +825,12 @@ IPDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 			ipdopts->param_status_ptr = (SQLUSMALLINT *) Value;
 			return ret;
 		case SQL_DESC_ROWS_PROCESSED_PTR:
-			ipdopts->param_processed_ptr = (SQLUINTEGER *) Value;
+			ipdopts->param_processed_ptr = (SQLULEN *) Value;
 			return ret;
 		case SQL_DESC_COUNT:
 			parameter_ibindings_set(ipdopts, CAST_PTR(SQLSMALLINT, Value), FALSE);
 			return ret;
-		case SQL_DESC_UNNAMED: /* only SQL_UNNAMED is allowed */ 
+		case SQL_DESC_UNNAMED: /* only SQL_UNNAMED is allowed */
 			if (SQL_UNNAMED !=  CAST_PTR(SQLSMALLINT, Value))
 			{
 				ret = SQL_ERROR;
@@ -899,7 +899,7 @@ inolog("IPDSetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 		case SQL_DESC_SCALE:
 			ipdopts->parameters[para_idx].decimal_digits = CAST_PTR(SQLSMALLINT, Value);
 			break;
-		case SQL_DESC_UNNAMED: /* only SQL_UNNAMED is allowed */ 
+		case SQL_DESC_UNNAMED: /* only SQL_UNNAMED is allowed */
 			if (SQL_UNNAMED !=  CAST_PTR(SQLSMALLINT, Value))
 			{
 				ret = SQL_ERROR;
@@ -909,7 +909,7 @@ inolog("IPDSetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 			else
 				NULL_THE_NAME(ipdopts->parameters[para_idx].paramName);
 			break;
-		case SQL_DESC_ALLOC_TYPE: /* read-only */ 
+		case SQL_DESC_ALLOC_TYPE: /* read-only */
 		case SQL_DESC_CASE_SENSITIVE: /* read-only */
 		case SQL_DESC_DATETIME_INTERVAL_PRECISION:
 		case SQL_DESC_FIXED_PREC_SCALE: /* read-only */
@@ -926,7 +926,7 @@ inolog("IPDSetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 		case SQL_DESC_UNSIGNED: /* read-only */
 		default:ret = SQL_ERROR;
 			DC_set_error(desc, DESC_INVALID_DESCRIPTOR_IDENTIFIER,
-				"invalid descriptor identifier"); 
+				"invalid descriptor identifier");
 	}
 	return ret;
 }
@@ -934,8 +934,8 @@ inolog("IPDSetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 
 static RETCODE SQL_API
 ARDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
-		SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength,
-		SQLINTEGER *StringLength)
+			SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength,
+			SQLINTEGER *StringLength)
 {
 	RETCODE		ret = SQL_SUCCESS;
 	SQLLEN		ival = 0;
@@ -992,7 +992,7 @@ ARDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 	{
 		case SQL_DESC_ARRAY_SIZE:
 			ival = opts->size_of_rowset;
-			break; 
+			break;
 		case SQL_DESC_ARRAY_STATUS_PTR:
 			rettype = SQL_IS_POINTER;
 			ptr = opts->row_operation_ptr;
@@ -1078,9 +1078,10 @@ ARDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 			break;
 		case SQL_DESC_DATETIME_INTERVAL_PRECISION:
 		case SQL_DESC_LENGTH:
-		default:ret = SQL_ERROR;
+		default:
+			ret = SQL_ERROR;
 			DC_set_error(desc, DESC_INVALID_DESCRIPTOR_IDENTIFIER,
-				"invalid descriptor identifier"); 
+				"invalid descriptor identifier");
 	}
 	switch (rettype)
 	{
@@ -1098,7 +1099,7 @@ ARDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 			*((void **) Value) = ptr;
 			break;
 	}
-			
+
 	if (StringLength)
 		*StringLength = len;
 	return ret;
@@ -1106,8 +1107,8 @@ ARDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 
 static RETCODE SQL_API
 APDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
-		SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength,
-		SQLINTEGER *StringLength)
+			SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength,
+			SQLINTEGER *StringLength)
 {
 	RETCODE		ret = SQL_SUCCESS;
 	SQLLEN		ival = 0;
@@ -1124,14 +1125,14 @@ APDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 		case SQL_DESC_BIND_OFFSET_PTR:
 		case SQL_DESC_BIND_TYPE:
 		case SQL_DESC_COUNT:
-			break; 
+			break;
 		default:if (RecNumber <= 0 || RecNumber > opts->allocated)
 			{
 inolog("APDGetField RecN=%d allocated=%d\n", RecNumber, opts->allocated);
 				DC_set_error(desc, DESC_BAD_PARAMETER_NUMBER_ERROR,
 					"bad parameter number");
 				return SQL_ERROR;
-			} 
+			}
 	}
 	para_idx = RecNumber - 1;
 	switch (FieldIdentifier)
@@ -1139,7 +1140,7 @@ inolog("APDGetField RecN=%d allocated=%d\n", RecNumber, opts->allocated);
 		case SQL_DESC_ARRAY_SIZE:
 			rettype = SQL_IS_LEN;
 			ival = opts->paramset_size;
-			break; 
+			break;
 		case SQL_DESC_ARRAY_STATUS_PTR:
 			rettype = SQL_IS_POINTER;
 			ptr = opts->param_operation_ptr;
@@ -1205,7 +1206,7 @@ inolog("APDGetField RecN=%d allocated=%d\n", RecNumber, opts->allocated);
 		case SQL_DESC_COUNT:
 			ret = SQL_IS_SMALLINT;
 			ival = opts->allocated;
-			break; 
+			break;
 		case SQL_DESC_ALLOC_TYPE: /* read-only */
 			rettype = SQL_IS_SMALLINT;
 			if (desc->embedded)
@@ -1228,7 +1229,7 @@ inolog("APDGetField RecN=%d allocated=%d\n", RecNumber, opts->allocated);
 		case SQL_DESC_LENGTH:
 		default:ret = SQL_ERROR;
 			DC_set_error(desc, DESC_INVALID_DESCRIPTOR_IDENTIFIER,
-					"invalid descriptor identifer"); 
+					"invalid descriptor identifer");
 	}
 	switch (rettype)
 	{
@@ -1250,7 +1251,7 @@ inolog("APDGetField RecN=%d allocated=%d\n", RecNumber, opts->allocated);
 			*((void **) Value) = ptr;
 			break;
 	}
-			
+
 	if (StringLength)
 		*StringLength = len;
 	return ret;
@@ -1258,8 +1259,8 @@ inolog("APDGetField RecN=%d allocated=%d\n", RecNumber, opts->allocated);
 
 static RETCODE SQL_API
 IRDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
-		SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength,
-		SQLINTEGER *StringLength)
+			SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength,
+			SQLINTEGER *StringLength)
 {
 	RETCODE		ret = SQL_SUCCESS;
 	SQLLEN		ival = 0;
@@ -1319,10 +1320,10 @@ IRDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 		case SQL_DESC_TYPE_NAME: /* read-only */
 			rettype = SQL_NTS;
 			bCallColAtt = TRUE;
-			break; 
+			break;
 		default:ret = SQL_ERROR;
 			DC_set_error(desc, DESC_INVALID_DESCRIPTOR_IDENTIFIER,
-				"invalid descriptor identifier"); 
+				"invalid descriptor identifier");
 	}
 	if (bCallColAtt)
 	{
@@ -1357,7 +1358,7 @@ IRDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 		case SQL_NTS:
 			break;
 	}
-			
+
 	if (StringLength)
 		*StringLength = len;
 	return ret;
@@ -1365,8 +1366,8 @@ IRDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 
 static RETCODE SQL_API
 IPDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
-		SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength,
-		SQLINTEGER *StringLength)
+			SQLSMALLINT FieldIdentifier, PTR Value, SQLINTEGER BufferLength,
+			SQLINTEGER *StringLength)
 {
 	RETCODE		ret = SQL_SUCCESS;
 	SQLINTEGER	ival = 0, len = 0, rettype = 0;
@@ -1379,7 +1380,7 @@ IPDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 		case SQL_DESC_ARRAY_STATUS_PTR:
 		case SQL_DESC_ROWS_PROCESSED_PTR:
 		case SQL_DESC_COUNT:
-			break; 
+			break;
 		default:if (RecNumber <= 0 || RecNumber > ipdopts->allocated)
 			{
 inolog("IPDGetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
@@ -1440,7 +1441,7 @@ inolog("IPDGetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 		case SQL_DESC_COUNT:
 			rettype = SQL_IS_SMALLINT;
 			ival = ipdopts->allocated;
-			break; 
+			break;
 		case SQL_DESC_PARAMETER_TYPE:
 			rettype = SQL_IS_SMALLINT;
 			ival = ipdopts->parameters[para_idx].paramType;
@@ -1469,7 +1470,7 @@ inolog("IPDGetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 		case SQL_DESC_ALLOC_TYPE: /* read-only */
 			rettype = SQL_IS_SMALLINT;
 			ival = SQL_DESC_ALLOC_AUTO;
-			break; 
+			break;
 		case SQL_DESC_CASE_SENSITIVE: /* read-only */
 		case SQL_DESC_DATETIME_INTERVAL_PRECISION:
 		case SQL_DESC_FIXED_PREC_SCALE: /* read-only */
@@ -1486,7 +1487,7 @@ inolog("IPDGetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 		case SQL_DESC_UNSIGNED: /* read-only */
 		default:ret = SQL_ERROR;
 			DC_set_error(desc, DESC_INVALID_DESCRIPTOR_IDENTIFIER,
-				"invalid descriptor identifier"); 
+				"invalid descriptor identifier");
 	}
 	switch (rettype)
 	{
@@ -1504,7 +1505,7 @@ inolog("IPDGetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 			*((void **)Value) = ptr;
 			break;
 	}
-			
+
 	if (StringLength)
 		*StringLength = len;
 	return ret;
@@ -1513,8 +1514,8 @@ inolog("IPDGetField RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 /*	SQLGetStmtOption -> SQLGetStmtAttr */
 RETCODE		SQL_API
 PGAPI_GetStmtAttr(HSTMT StatementHandle,
-		SQLINTEGER Attribute, PTR Value,
-		SQLINTEGER BufferLength, SQLINTEGER *StringLength)
+				  SQLINTEGER Attribute, PTR Value,
+				  SQLINTEGER BufferLength, SQLINTEGER *StringLength)
 {
 	CSTR func = "PGAPI_GetStmtAttr";
 	StatementClass *stmt = (StatementClass *) StatementHandle;
@@ -1529,7 +1530,7 @@ PGAPI_GetStmtAttr(HSTMT StatementHandle,
 			len = sizeof(SQLPOINTER);
 			break;
 		case SQL_ATTR_PARAM_BIND_OFFSET_PTR:	/* 17 */
-			*((SQLULEN **) Value) = (SQLULEN *) SC_get_APDF(stmt)->param_offset_ptr;
+			*((SQLULEN **) Value) = SC_get_APDF(stmt)->param_offset_ptr;
 			len = sizeof(SQLPOINTER);
 			break;
 		case SQL_ATTR_PARAM_BIND_TYPE:	/* 18 */
@@ -1545,15 +1546,15 @@ PGAPI_GetStmtAttr(HSTMT StatementHandle,
 			len = sizeof(SQLPOINTER);
 			break;
 		case SQL_ATTR_PARAMS_PROCESSED_PTR:		/* 21 */
-			*((SQLUINTEGER **) Value) = (SQLUINTEGER *) SC_get_IPDF(stmt)->param_processed_ptr;
+			*((SQLULEN **) Value) = SC_get_IPDF(stmt)->param_processed_ptr;
 			len = sizeof(SQLPOINTER);
 			break;
 		case SQL_ATTR_PARAMSET_SIZE:	/* 22 */
-			*((SQLUINTEGER *) Value) = (SQLUINTEGER) SC_get_APDF(stmt)->paramset_size;
+			*((SQLULEN *) Value) = SC_get_APDF(stmt)->paramset_size;
 			len = sizeof(SQLUINTEGER);
 			break;
 		case SQL_ATTR_ROW_BIND_OFFSET_PTR:		/* 23 */
-			*((SQLULEN **) Value) = (SQLULEN *) SC_get_ARDF(stmt)->row_offset_ptr;
+			*((SQLULEN **) Value) = SC_get_ARDF(stmt)->row_offset_ptr;
 			len = 4;
 			break;
 		case SQL_ATTR_ROW_OPERATION_PTR:		/* 24 */
@@ -1565,7 +1566,7 @@ PGAPI_GetStmtAttr(HSTMT StatementHandle,
 			len = 4;
 			break;
 		case SQL_ATTR_ROWS_FETCHED_PTR: /* 26 */
-			*((SQLULEN **) Value) = (SQLULEN *) SC_get_IRDF(stmt)->rowsFetched;
+			*((SQLULEN **) Value) = SC_get_IRDF(stmt)->rowsFetched;
 			len = 4;
 			break;
 		case SQL_ATTR_ROW_ARRAY_SIZE:	/* 27 */
@@ -1577,7 +1578,7 @@ PGAPI_GetStmtAttr(HSTMT StatementHandle,
 		case SQL_ATTR_IMP_ROW_DESC:		/* 10012 */
 		case SQL_ATTR_IMP_PARAM_DESC:	/* 10013 */
 			len = 4;
-			*((HSTMT *) Value) = descHandleFromStatementHandle(StatementHandle, Attribute); 
+			*((HSTMT *) Value) = descHandleFromStatementHandle(StatementHandle, Attribute);
 			break;
 
 		case SQL_ATTR_CURSOR_SCROLLABLE:		/* -1 */
@@ -1615,8 +1616,8 @@ PGAPI_GetStmtAttr(HSTMT StatementHandle,
 /*	SQLSetConnectOption -> SQLSetConnectAttr */
 RETCODE		SQL_API
 PGAPI_SetConnectAttr(HDBC ConnectionHandle,
-			SQLINTEGER Attribute, PTR Value,
-			SQLINTEGER StringLength)
+					 SQLINTEGER Attribute, PTR Value,
+					 SQLINTEGER StringLength)
 {
 	CSTR	func = "PGAPI_SetConnectAttr";
 	ConnectionClass *conn = (ConnectionClass *) ConnectionHandle;
@@ -1649,8 +1650,17 @@ PGAPI_SetConnectAttr(HDBC ConnectionHandle,
 #ifdef	WIN32
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 			mylog("SQL_ATTR_ENLIST_IN_DTC %p request received\n", Value);
-			if (conn->connInfo.xa_opt != 0)	
+			if (conn->connInfo.xa_opt != 0)
+			{
+				/*
+				 *	When a new global transaction is about
+				 *	to begin, isolate the existent global
+				 *	transaction.
+				 */
+				if (NULL != Value && CC_is_in_global_trans(conn))
+					CALL_IsolateDtcConn(conn, TRUE);
 				return CALL_EnlistInDtc(conn, Value, conn->connInfo.xa_opt);
+			}
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
 #endif /* WIN32 */
 			unsupported = TRUE;
@@ -1716,7 +1726,7 @@ PGAPI_SetConnectAttr(HDBC ConnectionHandle,
 			mylog("server_side_prepare => %d\n", conn->connInfo.use_server_side_prepare);
 			break;
 		case SQL_ATTR_PGOPT_FETCH:
-			conn->connInfo.drivers.fetch_max = CAST_UPTR(SQLINTEGER, Value);
+			conn->connInfo.drivers.fetch_max = CAST_PTR(int, Value);
 			qlog("fetch => %d\n", conn->connInfo.drivers.fetch_max);
 			mylog("fetch => %d\n", conn->connInfo.drivers.fetch_max);
 			break;
@@ -1736,9 +1746,9 @@ PGAPI_SetConnectAttr(HDBC ConnectionHandle,
 /*	new function */
 RETCODE		SQL_API
 PGAPI_GetDescField(SQLHDESC DescriptorHandle,
-			SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
-			PTR Value, SQLINTEGER BufferLength,
-			SQLINTEGER *StringLength)
+				   SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
+				   PTR Value, SQLINTEGER BufferLength,
+				   SQLINTEGER *StringLength)
 {
 	CSTR func = "PGAPI_GetDescField";
 	RETCODE		ret = SQL_SUCCESS;
@@ -1778,7 +1788,7 @@ PGAPI_GetDescField(SQLHDESC DescriptorHandle,
 					DC_set_errormsg(desc, "can't SQLGetDescField for this parameter number");
 					break;
 			}
-		} 
+		}
 		DC_log_error(func, "", desc);
 	}
 	return ret;
@@ -1787,8 +1797,8 @@ PGAPI_GetDescField(SQLHDESC DescriptorHandle,
 /*	new function */
 RETCODE		SQL_API
 PGAPI_SetDescField(SQLHDESC DescriptorHandle,
-			SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
-			PTR Value, SQLINTEGER BufferLength)
+				   SQLSMALLINT RecNumber, SQLSMALLINT FieldIdentifier,
+				   PTR Value, SQLINTEGER BufferLength)
 {
 	CSTR func = "PGAPI_SetDescField";
 	RETCODE		ret = SQL_SUCCESS;
@@ -1828,7 +1838,7 @@ PGAPI_SetDescField(SQLHDESC DescriptorHandle,
 					break;
 				break;
 			}
-		} 
+		}
 		DC_log_error(func, "", desc);
 	}
 	return ret;
@@ -1837,8 +1847,8 @@ PGAPI_SetDescField(SQLHDESC DescriptorHandle,
 /*	SQLSet(Param/Scroll/Stmt)Option -> SQLSetStmtAttr */
 RETCODE		SQL_API
 PGAPI_SetStmtAttr(HSTMT StatementHandle,
-		SQLINTEGER Attribute, PTR Value,
-		SQLINTEGER StringLength)
+				  SQLINTEGER Attribute, PTR Value,
+				  SQLINTEGER StringLength)
 {
 	RETCODE	ret = SQL_SUCCESS;
 	CSTR func = "PGAPI_SetStmtAttr";
@@ -1867,7 +1877,7 @@ PGAPI_SetStmtAttr(HSTMT StatementHandle,
 			return SQL_ERROR;
 
 		case SQL_ATTR_METADATA_ID:		/* 10014 */
-			stmt->options.metadata_id = CAST_UPTR(SQLUINTEGER, Value); 
+			stmt->options.metadata_id = CAST_UPTR(SQLUINTEGER, Value);
 			break;
 		case SQL_ATTR_APP_ROW_DESC:		/* 10010 */
 			if (SQL_NULL_HDESC == Value)
@@ -1875,7 +1885,7 @@ PGAPI_SetStmtAttr(HSTMT StatementHandle,
 				stmt->ard = &(stmt->ardi);
 			}
 			else
-			{ 
+			{
 				stmt->ard = (ARDClass *) Value;
 inolog("set ard=%p\n", stmt->ard);
 			}
@@ -1886,7 +1896,7 @@ inolog("set ard=%p\n", stmt->ard);
 				stmt->apd = &(stmt->apdi);
 			}
 			else
-			{ 
+			{
 				stmt->apd = (APDClass *) Value;
 			}
 			break;
@@ -1906,10 +1916,10 @@ inolog("set ard=%p\n", stmt->ard);
 			SC_get_IPDF(stmt)->param_status_ptr = (SQLUSMALLINT *) Value;
 			break;
 		case SQL_ATTR_PARAMS_PROCESSED_PTR:		/* 21 */
-			SC_get_IPDF(stmt)->param_processed_ptr = (SQLUINTEGER *) Value;
+			SC_get_IPDF(stmt)->param_processed_ptr = (SQLULEN *) Value;
 			break;
 		case SQL_ATTR_PARAMSET_SIZE:	/* 22 */
-			SC_get_APDF(stmt)->paramset_size = CAST_UPTR(SQLUINTEGER, Value);
+			SC_get_APDF(stmt)->paramset_size = CAST_UPTR(SQLULEN, Value);
 			break;
 		case SQL_ATTR_ROW_BIND_OFFSET_PTR:		/* 23 */
 			SC_get_ARDF(stmt)->row_offset_ptr = (SQLULEN *) Value;
@@ -1934,7 +1944,7 @@ inolog("set ard=%p\n", stmt->ard);
 
 #define	CALC_BOOKMARK_ADDR(book, offset, bind_size, index) \
 	(book->buffer + offset + \
-	(bind_size > 0 ? bind_size : (SQL_C_VARBOOKMARK == book->returntype ? book->buflen : sizeof(UInt4))) * index)    	
+	(bind_size > 0 ? bind_size : (SQL_C_VARBOOKMARK == book->returntype ? book->buflen : sizeof(UInt4))) * index)
 
 /*	SQL_NEED_DATA callback for PGAPI_BulkOperations */
 typedef struct
@@ -1947,7 +1957,7 @@ typedef struct
 	int		idx, processed;
 }	bop_cdata;
 
-static 
+static
 RETCODE	bulk_ope_callback(RETCODE retcode, void *para)
 {
 	RETCODE	ret = retcode;
@@ -2033,7 +2043,7 @@ PGAPI_BulkOperations(HSTMT hstmt, SQLSMALLINT operationX)
 	s.operation = operationX;
 	SC_clear_error(s.stmt);
 	s.opts = SC_get_ARDF(s.stmt);
-	
+
 	s.auto_commit_needed = FALSE;
 	if (SQL_FETCH_BY_BOOKMARK != s.operation)
 	{
@@ -2056,5 +2066,5 @@ PGAPI_BulkOperations(HSTMT hstmt, SQLSMALLINT operationX)
 	if (s.stmt->internal)
 		ret = DiscardStatementSvp(s.stmt, ret, FALSE);
 	return ret;
-}	
+}
 #endif /* ODBCVER >= 0x0300 */
