@@ -1,4 +1,4 @@
-/* File:			enlsit.h
+/* File:			enlist.h
  *
  * Description:		See "msdtc_enlist.c"
  *
@@ -9,16 +9,14 @@
 #ifndef __PGENLIST_H__
 #define __PGENLIST_H__
 
-#include "connection.h"
-
 #ifdef	__cplusplus
 extern "C" {
 #endif
 #ifdef	WIN32
 #ifdef	_HANDLE_ENLIST_IN_DTC_
-RETCODE	EnlistInDtc(ConnectionClass *conn, void *pTra, int method);
-RETCODE	DtcOnDisconnect(ConnectionClass *);
-RETCODE	DtcOnRelease(void);
+RETCODE	EnlistInDtc(void *conn, void *pTra, int method);
+RETCODE	DtcOnDisconnect(void *);
+RETCODE	IsolateDtcConn(void *, BOOL continueConnection);
 const char *GetXaLibName(void);
 const char *GetXaLibPath(void);
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
