@@ -2,7 +2,7 @@
  *
  * Description:		See "pgtypes.c"
  *
- * Comments:		See "notice.txt" for copyright and license information.
+ * Comments:		See "readme.txt" for copyright and license information.
  *
  */
 
@@ -80,6 +80,7 @@
 #define PG_TYPE_UUID			2950
 #define INTERNAL_ASIS_TYPE		(-9999)
 
+#define TYPE_MAY_BE_ARRAY(type) ((type) == PG_TYPE_XMLARRAY || ((type) >= 1000 && (type) <= 1041))
 /* extern Int4 pgtypes_defined[]; */
 extern SQLSMALLINT sqlTypes[];
 
@@ -89,7 +90,7 @@ extern SQLSMALLINT sqlTypes[];
 #define PG_WIDTH_OF_BOOLS_AS_CHAR		5
 
 #if (ODBCVER >= 0x0300)
-/* 
+/*
  *	SQL_INTERVAL support is disabled because I found
  *	some applications which are unhappy with it.
  *
@@ -103,7 +104,6 @@ OID		sqltype_to_pgtype(const ConnectionClass *conn, SQLSMALLINT fSqlType);
 SQLSMALLINT	pgtype_to_concise_type(const StatementClass *stmt, OID type, int col);
 SQLSMALLINT	pgtype_to_sqldesctype(const StatementClass *stmt, OID type, int col);
 SQLSMALLINT	pgtype_to_datetime_sub(const StatementClass *stmt, OID type, int col);
-SQLSMALLINT	pgtype_to_ctype(const StatementClass *stmt, OID type, int col);
 const char	*pgtype_to_name(const StatementClass *stmt, OID type, int col, BOOL auto_increment);
 
 SQLSMALLINT	pgtype_attr_to_concise_type(const ConnectionClass *conn, OID type, int typmod, int adtsize_or_longestlen);
@@ -116,11 +116,14 @@ Int4		pgtype_attr_buffer_length(const ConnectionClass *conn, OID type, int attty
 Int4		pgtype_attr_display_size(const ConnectionClass *conn, OID type, int atttypmod, int adtsize_or_longestlen, int handle_unknown_size_as);
 Int2		pgtype_attr_decimal_digits(const ConnectionClass *conn, OID type, int atttypmod, int adtsize_or_longestlen, int handle_unknown_size_as);
 Int4		pgtype_attr_transfer_octet_length(const ConnectionClass *conn, OID type, int atttypmod, int handle_unknown_size_as);
+SQLSMALLINT	pgtype_attr_precision(const ConnectionClass *conn, OID type, int atttypmod, int adtsize_or_longest, int handle_unknown_size_as);
+Int4		pgtype_attr_desclength(const ConnectionClass *conn, OID type, int atttypmod, int adtsize_or_longestlen, int handle_unknown_size_as);
+Int2		pgtype_attr_scale(const ConnectionClass *conn, OID type, int atttypmod, int adtsize_or_longestlen, int handle_unknown_size_as);
 
 /*	These functions can use static numbers or result sets(col parameter) */
 Int4		pgtype_column_size(const StatementClass *stmt, OID type, int col, int handle_unknown_size_as); /* corresponds to "precision" in ODBC 2.x */
 SQLSMALLINT	pgtype_precision(const StatementClass *stmt, OID type, int col, int handle_unknown_size_as); /* "precsion in ODBC 3.x */
-/* the following size/length are of Int4 due to PG restriction */ 
+/* the following size/length are of Int4 due to PG restriction */
 Int4		pgtype_display_size(const StatementClass *stmt, OID type, int col, int handle_unknown_size_as);
 Int4		pgtype_buffer_length(const StatementClass *stmt, OID type, int col, int handle_unknown_size_as);
 Int4		pgtype_desclength(const StatementClass *stmt, OID type, int col, int handle_unknown_size_as);
