@@ -32,9 +32,9 @@ int	platformId = 0;
 #endif
 
 static int	exepgm = 0;
-BOOL isMsAccess() {return 1 == exepgm;}
-BOOL isMsQuery() {return 2 == exepgm;}
-BOOL isSqlServr() {return 3 == exepgm;}
+BOOL isMsAccess(void) {return 1 == exepgm;}
+BOOL isMsQuery(void) {return 2 == exepgm;}
+BOOL isSqlServr(void) {return 3 == exepgm;}
 
 GLOBAL_VALUES globals;
 
@@ -171,7 +171,7 @@ DllMain(HANDLE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
 			{
 				char	pathname[_MAX_PATH], fname[_MAX_FNAME];
 				OSVERSIONINFO	osversion;
-				
+
 				getCommonDefaults(DBMS_NAME, ODBCINST_INI, NULL);
 				if (GetModuleFileName(NULL, pathname, sizeof(pathname)) > 0)
 				{
