@@ -109,9 +109,9 @@ struct addrinfo
 #define	EINPROGRESS	WSAEINPROGRESS
 #endif /* EINPROGRESS */
 #endif /* WIN32 */
-typedef void (WSAAPI *freeaddrinfo_func) (struct addrinfo *); 
+typedef void (WSAAPI *freeaddrinfo_func) (struct addrinfo *);
 typedef int (WSAAPI *getaddrinfo_func) (const char *, const char *,
-	const struct addrinfo *, struct addrinfo **); 
+	const struct addrinfo *, struct addrinfo **);
 typedef int (WSAAPI *getnameinfo_func) (const struct sockaddr *,
 	socklen_t, char *, size_t, char *, size_t, int);
 typedef int (WSAAPI *inet_pton_func) (int, const char *, void *);
@@ -167,10 +167,10 @@ struct SocketClass_
 	/* SSL stuff */
 	void		*ssl;		/* libpq ssl */
 #endif /* USE_SSL */
-#ifndef	NOT_USE_LIBPQ
+#ifdef	USE_LIBPQ
 	void		*pqconn;	/* libpq PGConn */
 	BOOL		via_libpq;	/* using libpq library ? */
-#endif /* NOT_USE_LIBPQ */
+#endif /* USE_LIBPQ */
 #ifdef	USE_GSS
 	gss_ctx_id_t	gctx;		/* GSS context */
 	gss_name_t	gtarg_nam;	/* GSS target name */
