@@ -44,7 +44,7 @@ typedef enum
  *		the least code number.
  *		The code for STMT_OK is 0 and error
  *		codes follow after it.
- */ 	
+ */
 enum {
 	LOWEST_STMT_ERROR		=		(-6)
 	/* minus values mean warning returns */
@@ -71,7 +71,7 @@ enum {
 	,STMT_STILL_EXECUTING
 	,STMT_NOT_IMPLEMENTED_ERROR
 	,STMT_BAD_PARAMETER_NUMBER_ERROR
-	,STMT_OPTION_OUT_OF_RANGE_ERROR	
+	,STMT_OPTION_OUT_OF_RANGE_ERROR
 	,STMT_INVALID_COLUMN_NUMBER_ERROR
 	,STMT_RESTRICTED_DATA_TYPE_ERROR
 	,STMT_INVALID_CURSOR_STATE_ERROR
@@ -266,7 +266,7 @@ struct StatementClass_
 	SQLLEN		diag_row_count;
 	char		*load_statement; /* to (re)load updatable individual rows */
 	char		*execute_statement; /* to execute the prepared plans */
-	Int4		from_pos;	
+	Int4		from_pos;
 	Int4		where_pos;
 	SQLLEN		last_fetch_count_include_ommitted;
 	time_t		stmt_time;
@@ -380,9 +380,9 @@ enum {
 enum
 {
 	NOT_YET_PREPARED = 0
-	,PREPARING_PERMANENTLY 
+	,PREPARING_PERMANENTLY
 	,PREPARING_TEMPORARILY
-	,PREPARED_PERMANENTLY 
+	,PREPARED_PERMANENTLY
 	,PREPARED_TEMPORARILY
 	,ONCE_DESCRIBED
 };
@@ -422,7 +422,13 @@ enum
 #define SC_ref_CC_error(a)	((a->ref_CC_error) = TRUE)
 void SC_forget_unnamed(StatementClass *self);
 #define SC_can_parse_statement(a) (STMT_TYPE_SELECT == (a)->statement_type)
-#define SC_may_use_cursor(a) (STMT_TYPE_SELECT == (a)->statement_type || STMT_TYPE_WITH == (a)->statement_type)
+/*
+ * DECLARE CURSOR + FETCH can only be used with SELECT-type queries. And
+ * it's not currently supported with array-bound parameters.
+ */
+#define SC_may_use_cursor(a) \
+	(SC_get_APDF(a)->paramset_size <= 1 &&								\
+	 (STMT_TYPE_SELECT == (a)->statement_type || STMT_TYPE_WITH == (a)->statement_type) )
 #define SC_may_fetch_rows(a) (STMT_TYPE_SELECT == (a)->statement_type || STMT_TYPE_WITH == (a)->statement_type)
 #define SC_can_req_colinfo(a) (STMT_TYPE_SELECT == (a)->statement_type || \
 		 STMT_TYPE_WITH == (a)->statement_type || \
@@ -501,8 +507,6 @@ BOOL	SC_SetExecuting(StatementClass *self, BOOL on);
 BOOL	SC_SetCancelRequest(StatementClass *self);
 BOOL	SC_AcceptedCancelRequest(const StatementClass *self);
 
-DescriptorClass	*SC_set_ARD(StatementClass *stmt, DescriptorClass *desc);
-DescriptorClass	*SC_set_APD(StatementClass *stmt, DescriptorClass *desc);
 int		enqueueNeedDataCallback(StatementClass *self, NeedDataCallfunc, void *);
 RETCODE		dequeueNeedDataCallback(RETCODE, StatementClass *self);
 void		cancelNeedDataState(StatementClass *self);
